#
# spec file for package shorewall
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define have_systemd 1
%define dmaj 5.2
%define dmin 5.2.8
# Warn users for upgrading configuration but only on major or minor version changes
%define conf_need_update 0
#2017+ New fillup location
%if ! %{defined _fillupdir}
  %define _fillupdir %{_localstatedir}/adm/fillup-templates
%endif
%{!?_distconfdir: %global _distconfdir %{_prefix}%{_sysconfdir}}
Name:           shorewall
Version:        5.2.8
Release:        6.3
Summary:        An iptables-based firewall for Linux systems
License:        GPL-2.0-only
Group:          Productivity/Networking/Security
URL:            http://www.shorewall.net/
Source:         http://www.shorewall.net/pub/shorewall/%{dmaj}/shorewall-%{dmin}/%{name}-%version.tar.bz2
Source1:        http://www.shorewall.net/pub/shorewall/%{dmaj}/shorewall-%{dmin}/%{name}-core-%version.tar.bz2
Source2:        http://www.shorewall.net/pub/shorewall/%{dmaj}/shorewall-%{dmin}/%{name}-lite-%version.tar.bz2
Source3:        http://www.shorewall.net/pub/shorewall/%{dmaj}/shorewall-%{dmin}/%{name}-init-%version.tar.bz2
Source4:        http://www.shorewall.net/pub/shorewall/%{dmaj}/shorewall-%{dmin}/%{name}6-lite-%version.tar.bz2
Source5:        http://www.shorewall.net/pub/shorewall/%{dmaj}/shorewall-%{dmin}/%{name}6-%version.tar.bz2
Source6:        http://www.shorewall.net/pub/shorewall/%{dmaj}/shorewall-%{dmin}/%{name}-docs-html-%version.tar.bz2
Source7:        %{name}-5.2.rpmlintrc
Source8:        README.openSUSE
# PATCH-FIX-OPENSUSE Shorewall-init use of fillup template
Patch1:         shorewall-init-fillup-install.patch
# PATCH-FIX-OPENSUSE Shorewall (6) use of fillup template
Patch2:         shorewall-fillup-install.patch
# PATCH-FIX-OPENSUSE Shorewall-lite (6) use of fillup template
Patch3:         shorewall-lite-fillup-install.patch
# PATH-FIX-OPENSUSE invalid manpage boo#1203006
Patch4:         shorewall-fix-install-manpages.patch
BuildRequires:  bash >= 4
BuildRequires:  perl-base
BuildRequires:  pkgconfig
BuildRequires:  perl(Digest::SHA)
BuildRequires:  pkgconfig(systemd)
Requires:       %{_sbindir}/service
Requires:       %{name}-core = %{version}-%{release}
Requires:       bc
Requires:       iproute2
Requires:       iptables
Requires:       logrotate
Requires:       perl-base
PreReq:         %fillup_prereq
Suggests:       xtables-addons
Provides:       shoreline_firewall = %{version}-%{release}
BuildArch:      noarch
%{?systemd_ordering}
%{perl_requires}

%description
The Shoreline Firewall, more commonly known as "Shorewall", is a Netfilter
(iptables) based firewall that can be used on a dedicated firewall system,
a multi-function gateway/ router/server or on a standalone GNU/Linux system.

%package lite
Summary:        Shoreline Firewall Lite is an iptables-based firewall for Linux systems
License:        GPL-2.0-only
Group:          Productivity/Networking/Security
Requires:       %{_sbindir}/service
Requires:       %{name}-core = %{version}-%{release}
Requires:       bc
Requires:       iproute2
Requires:       iptables
Requires:       logrotate
PreReq:         %fillup_prereq
Provides:       shoreline_firewall = %{version}-%{release}
%{?systemd_requires}

%description lite
The Shoreline Firewall, more commonly known as "Shorewall", is a Netfilter
(iptables) based firewall that can be used on a dedicated firewall system,
a multi-function gateway/ router/server or on a standalone GNU/Linux system.

Shorewall Lite is a companion product to Shorewall that allows network
administrators to centralize the configuration of Shorewall-based firewalls.

%package -n %{name}6
Summary:        Shoreline Firewall 6 is an ip6tables-based firewall for Linux systems
License:        GPL-2.0-only
Group:          Productivity/Networking/Security
Requires:       %{_sbindir}/service
Requires:       %{name}-core = %{version}-%{release}
Requires:       bc
Requires:       iproute2
Requires:       iptables
Requires:       logrotate
Requires:       perl-base
PreReq:         %fillup_prereq
Provides:       shoreline_firewall = %{version}-%{release}
%{?systemd_requires}

%description -n %{name}6
The Shoreline Firewall 6, more commonly known as "Shorewall6", is a Netfilter
(ip6tables) based IPv6 firewall that can be used on a dedicated firewall system,
a multi-function gateway/ router/server or on a standalone GNU/Linux system.

%package -n %{name}6-lite
Summary:        Shoreline Firewall 6 Lite is an ip6tables-based firewall for Linux systems
License:        GPL-2.0-only
Group:          Productivity/Networking/Security
Requires:       %{_sbindir}/service
Requires:       %{name}-core = %{version}-%{release}
Requires:       bc
Requires:       iproute2
Requires:       iptables
Requires:       logrotate
PreReq:         %fillup_prereq
Provides:       shoreline_firewall = %{version}-%{release}
%{?systemd_requires}

%description -n %{name}6-lite
The Shoreline Firewall 6, more commonly known as "Shorewall6", is a Netfilter
(ip6tables) based firewall that can be used on a dedicated firewall system,
a multi-function gateway/ router/server or on a standalone GNU/Linux system.

Shorewall6 Lite is a companion product to Shorewall6 that allows network
administrators to centralize the configuration of Shorewall6-based firewalls.

%package  init
Summary:        Adds functionality during boot to Shoreline Firewall (Shorewall)
License:        GPL-2.0-only
Group:          Productivity/Networking/Security
Requires:       %{_sbindir}/service
Requires:       logrotate
Requires:       shoreline_firewall = %{version}-%{release}
PreReq:         %fillup_prereq
%{?systemd_requires}

%description init
The Shoreline Firewall, more commonly known as "Shorewall", is a Netfilter
(iptables) based firewall that can be used on a dedicated firewall system,
a multi-function gateway/ router/server or on a standalone GNU/Linux system.

Shorewall Init is a companion product to Shorewall that allows for tigher
control of connections during boot and that integrates Shorewall with
ifup/ifdown and NetworkManager.

%package  docs
Summary:        HTML documentation for shorewall configuration
License:        GFDL-1.1-only
Group:          Documentation/Other

%description  docs
HTML documentation for the Shoreline Firewall. Highly recommend to read before
starting to configure shorewall

%package core
Summary:        Core libraries for Shorewall
License:        GPL-2.0-only
Group:          Productivity/Networking/Security
Requires:       iptables
Requires:       perl-base

%description core
This package contains the core libraries for Shorewall.

%prep
%setup -q -c -a1 -a2 -a3 -a4 -a5 -a6
#PATCH-FIX-OPENSUSE geo_ip has no LE
#We keep it with this dynamic form to avoid maintaining manual patch
find . \( -name shorewall*.conf -or -name shorewall*.conf.annotated \) -exec sed -i "s,GEOIPDIR=%{_datadir}/xt_geoip/LE,GEOIPDIR=%{_datadir}/xt_geoip,g" {} \;
#PATCH-FIX-OPENSUSUSE for fillup
pushd %{name}-init-%{version}
%patch -P 1 -p1
popd
pushd %{name}-%{version}
%patch -P 2 -p1
%patch -P 4 -p1
popd
pushd %{name}6-%{version}
%patch -P 2 -p1
%patch -P 4 -p1
popd
pushd %{name}-lite-%{version}
%patch -P 3 -p1
popd
pushd %{name}6-lite-%{version}
%patch -P 3 -p1
popd

chmod -x %{name}-docs-html-%{version}/images/*.png
chmod -x %{name}6-%{version}/tunnel
chmod -x %{name}6-%{version}/ipv6
chmod -x %{name}-%{version}/Contrib/swping.init
chmod -x %{name}-%{version}/Contrib/tunnel

cp %{SOURCE8} %{name}-%{version}/.

# We don't have /sbin /bin merged on /usr so symlinks can't work.
# so we dynamically patch last /sbin calls in lib.cli-std
# and make shorewall remote working without hacks
sed -i 's#/sbin/shorewall#%{_sbindir}/shorewall#g' %{name}-%{version}/lib.cli-std

# On 20201108 Upstream decide to remove StandardOutput=syslog from service on future version
find . -iname "*.service" -exec sed -i '/StandardOutput=syslog/d' {} \;

%build

%install

# find the systemd version in order to install correct service files
%define systemd_version \
systemd --version | awk '/^systemd/ {print $2}'

# NOTE For REVIEWERS
#
# configure is used to set the installation parameters to shorewall.
# The default shorewallrc is not what we want and every distro needs
# to set it differently. Please see the disccussion in
# http://lists.opensuse.org/opensuse-packaging/2012-08/msg00050.html

targets="shorewall shorewall-core shorewall-lite shorewall6 shorewall6-lite shorewall-init"

for i in $targets; do
    pushd ${i}-%{version}
    ./configure \
        vendor=%{_vendor} \
        host=%{_vendor} \
        prefix=%{_prefix} \
        perllibdir=%{perl_vendorlib} \
        libexecdir=%{_libexecdir} \
        sbindir=%{_sbindir} \
        %if 0%{?have_systemd}
            servicedir=%{_unitdir} \
            initdir= \
        %endif
       sharedir=%{_datadir}

    if [ $i != shorewall-init ];
    then
        BUILD=suse DESTDIR=%{buildroot} FILLUPDIR=%{_fillupdir} ./install.sh shorewallrc
    else
        install -d %buildroot/%{_sysconfdir}/NetworkManager/dispatcher.d
        BUILD=suse DESTDIR=%{buildroot} FILLUPDIR=%{_fillupdir} ./install.sh shorewallrc

        if [ -f ${DESTDIR}%{_sysconfdir}/ppp ]; then
            for directory in ip-up.d ip-down.d ipv6-up.d ipv6-down.d; do
                mkdir -p ${DESTDIR}%{_sysconfdir}/ppp/$directory #SuSE doesn't create the IPv6 directories
                cp -fp ${DESTDIR}${LIBEXEC}/shorewall-init/ifupdown ${DESTDIR}%{_sysconfdir}/ppp/$directory/shorewall
            done
        fi
        # Move Networkmanager to _prefix
        if [ -d "%buildroot/%{_sysconfdir}/NetworkManager/dispatcher.d" ]; then
            install -d "%buildroot/%{_prefix}/lib/NetworkManager/"
            mv -v "%buildroot/%{_sysconfdir}/NetworkManager/dispatcher.d" "%buildroot/%{_prefix}/lib/NetworkManager/dispatcher.d"
        fi
        # Move logrotate.d files to _prefix
        if [ -d "%{buildroot}%{_sysconfdir}/logrotate.d" ]; then
            install -d "%{buildroot}%{_distconfdir}"
            mv -v "%{buildroot}%{_sysconfdir}/logrotate.d" "%{buildroot}%{_distconfdir}/logrotate.d"
        fi
    fi
    popd
done

rctargets="shorewall shorewall-lite shorewall6 shorewall6-lite shorewall-init"
mkdir -p %buildroot/%{_sbindir}
for i in $rctargets; do
  ln -sf %{_sbindir}/service %buildroot%{_sbindir}/rc${i}
done

# starting with 12.3 drop sysv-init support fedora already did
rm -rf %buildroot%_initddir

# Since 5.12 we need to remove them again
rm -f %{buildroot}/%{_sysconfdir}/sysconfig/%{name}*

# Move
%pre
%service_add_pre shorewall.service
%if %conf_need_update
echo "upgrade configuration" > /run/%{name}_upgrade
%endif

%post
%service_add_post shorewall.service

%preun
rm -f %{_sysconfdir}/%{name}/startup_disabled
%service_del_preun shorewall.service

%postun
%service_del_postun shorewall.service

%posttrans
if [ -f /run/%{name}_upgrade ]; then
cat > %{_localstatedir}/adm/update-messages/%{name}-%{version}-something << EOF
Warning: Shorewall %{dmaj} has just been installed
Warning: You have to check and upgrade your configuration
%{name} update -a %{_sysconfdir}/%{name}
Warning: Adjust changes and try the new configuration
%{name} try %{_sysconfdir}/%{name}
Warning: If everything work run
systemctl try-reload-or-restart %{name}
EOF
rm -f /run/%{name}_upgrade
fi

%pre -n %{name}6
%service_add_pre shorewall6.service
%if %conf_need_update
echo "upgrade configuration" > /run/%{name}6_upgrade
%endif

%post -n %{name}6
%service_add_post shorewall6.service

%preun -n %{name}6
rm -f %{_sysconfdir}/%{name}/startup_disabled
%service_del_preun shorewall6.service

%postun -n %{name}6
%service_del_postun shorewall6.service

%posttrans -n %{name}6
if [ -f /run/%{name}6_upgrade ]; then
cat > %{_localstatedir}/adm/update-messages/%{name}-%{version}-something << EOF
Warning: Shorewall6 %{dmaj} has just been installed
Warning: You have to check and upgrade your configuration
%{name}6 update -a %{_sysconfdir}/%{name}6
Warning: Adjust changes and try the new configuration
%{name}6 try %{_sysconfdir}/%{name}6
Warning: If everything work run
systemctl try-reload-or-restart %{name}6
EOF
rm -f /run/%{name}6_upgrade
fi

%pre -n %{name}-lite
%service_add_pre shorewall-lite.service

%post -n %{name}-lite
%service_add_post shorewall-lite.service

%preun -n %{name}-lite
rm -f %{_sysconfdir}/%{name}/startup_disabled
%service_del_preun shorewall-lite.service

%postun -n %{name}-lite
%service_del_postun shorewall-lite.service

%pre -n %{name}6-lite
%service_add_pre shorewall6-lite.service

%post -n %{name}6-lite
%service_add_post shorewall6-lite.service

%preun -n %{name}6-lite
rm -f %{_sysconfdir}/%{name}/startup_disabled
%service_del_preun shorewall6-lite.service

%postun -n %{name}6-lite
%service_del_postun shorewall6-lite.service

%pre init
%service_add_pre shorewall-init.service

%post init
%{fillup_only}
%service_add_post shorewall-init.service

%preun init
%service_del_preun shorewall-init.service

%postun init
# boo#1166114 Never try to restart shorewall-init
# You can lock down the system so never use
#%%service_del_postun shorewall-init.service macro
%systemd_postun shorewall-init.service

%files
%defattr(-,root,root,-)
%doc %{name}-%version/{COPYING,changelog.txt,releasenotes.txt,README.openSUSE}
%{_sbindir}/rc%{name}
%{_fillupdir}/sysconfig.%{name}
%dir %{_sysconfdir}/%{name}
%ghost %{_sysconfdir}/%{name}/isusable
%config(noreplace) %{_sysconfdir}/%{name}/*
%dir %{_datadir}/%{name}
%dir %{_libexecdir}/%{name}
%dir %{_datadir}/%{name}/configfiles
%dir %{_datadir}/%{name}/deprecated
%dir %{_datadir}/%{name}/Shorewall
%attr(0700,root,root) %dir %{_localstatedir}/lib/%{name}
%dir %{_distconfdir}
%dir %{_distconfdir}/logrotate.d/
%{_distconfdir}/logrotate.d/%{name}
%{_datadir}/%{name}/version
%{_datadir}/%{name}/actions.std
%{_datadir}/%{name}/action.*
%{_datadir}/%{name}/lib.base
%{_datadir}/%{name}/macro.*
%{_datadir}/%{name}/prog.*
%{_datadir}/%{name}/helpers
%{_datadir}/%{name}/configpath
%{_datadir}/%{name}/configfiles/*
%attr(755,root,root) %{_libexecdir}/%{name}/getparams
%attr(755,root,root) %{_libexecdir}/%{name}/compiler.pl
%dir %{perl_vendorlib}/Shorewall
%{perl_vendorlib}/Shorewall/*.pm
%{_mandir}/man5/%{name}-[a-k,m-z]*.5*
%{_mandir}/man5/%{name}-logging.5*
%{_mandir}/man5/%{name}.conf.5*
%{_mandir}/man8/%{name}.8*
%attr(644,root,root) %{_unitdir}/%{name}.service

%files lite
%defattr(-,root,root,-)
%doc %{name}-lite-%version/{COPYING,changelog.txt,releasenotes.txt}
%{_fillupdir}/sysconfig.%{name}-lite
%dir %{_sysconfdir}/%{name}-lite
%attr(0644,root,root) %config(noreplace) %{_sysconfdir}/%{name}-lite/%{name}-lite.conf
%{_sbindir}/rc%{name}-lite
%{_sbindir}/%{name}-lite
%dir %{_datadir}/%{name}-lite
%dir %{_libexecdir}/%{name}-lite
%attr(0700,root,root) %dir %{_localstatedir}/lib/%{name}-lite
%dir %{_distconfdir}
%dir %{_distconfdir}/logrotate.d/
%{_distconfdir}/logrotate.d/%{name}-lite
%{_datadir}/%{name}-lite/version
%{_datadir}/%{name}-lite/configpath
%attr(- ,root,root) %{_datadir}/%{name}-lite/functions
%{_datadir}/%{name}-lite/lib.base
%{_datadir}/%{name}-lite/helpers
%attr(0544,root,root) %{_libexecdir}/%{name}-lite/shorecap
%{_mandir}/man5/%{name}-lite*.5*
%{_mandir}/man8/%{name}-lite.8.*
%attr(644,root,root) %{_unitdir}/%{name}-lite.service

%files -n %{name}6
%defattr(-,root,root,-)
%doc %{name}6-%version/{COPYING,changelog.txt,releasenotes.txt,tunnel,ipv6,ipsecvpn}
%{_sbindir}/rc%{name}6
%{_sbindir}/%{name}6
%{_fillupdir}/sysconfig.%{name}6
%dir %{_sysconfdir}/%{name}6
%ghost %{_sysconfdir}/%{name}6/isusable
%config(noreplace) %{_sysconfdir}/%{name}6/*
%dir %{_datadir}/%{name}6
%dir %{_libexecdir}/%{name}6
%dir %{_datadir}/%{name}6/configfiles
%dir %{_datadir}/%{name}6/deprecated
%attr(0700,root,root) %dir %{_localstatedir}/lib/%{name}6
%dir %{_distconfdir}
%dir %{_distconfdir}/logrotate.d/
%{_distconfdir}/logrotate.d/%{name}6
%{_datadir}/%{name}6/version
%{_datadir}/%{name}6/actions.std
%{_datadir}/%{name}6/action.*
%{_datadir}/%{name}6/functions
%{_datadir}/%{name}6/lib.base
%{_datadir}/%{name}6/macro.*
%{_datadir}/%{name}6/helpers
%{_datadir}/%{name}6/configpath
%{_datadir}/%{name}6/configfiles/*
%{_mandir}/man5/%{name}6-[a-k,m-z]*.5*
%{_mandir}/man5/%{name}6.conf.5*
%{_mandir}/man8/%{name}6.8*
%attr(644,root,root) %{_unitdir}/%{name}6.service

%files -n %{name}6-lite
%defattr(-,root,root,-)
%{_mandir}/man5/%{name}6-lite*.5*
%{_mandir}/man8/%{name}6-lite.8*
%doc %{name}6-lite-%version/{COPYING,changelog.txt,releasenotes.txt}
%{_fillupdir}/sysconfig.%{name}6-lite
%dir %{_sysconfdir}/%{name}6-lite
%attr(0644,root,root) %config(noreplace) %{_sysconfdir}/%{name}6-lite/%{name}6-lite.conf
%{_sbindir}/rc%{name}6-lite
%{_sbindir}/%{name}6-lite
%dir %{_datadir}/%{name}6-lite
%dir %{_libexecdir}/%{name}6-lite
%attr(0700,root,root) %dir %{_localstatedir}/lib/%{name}6-lite
%dir %{_distconfdir}
%dir %{_distconfdir}/logrotate.d/
%{_distconfdir}/logrotate.d/%{name}6-lite
%{_datadir}/%{name}6-lite/version
%{_datadir}/%{name}6-lite/configpath
%attr(- ,root,root) %{_datadir}/%{name}6-lite/functions
%{_datadir}/%{name}6-lite/lib.base
%{_datadir}/%{name}6-lite/helpers
%attr(0544,root,root) %{_libexecdir}/%{name}6-lite/shorecap
%attr(644,root,root) %{_unitdir}/%{name}6-lite.service

%files init
%defattr(-,root,root,-)
%doc %{name}-init-%version/{COPYING,changelog.txt,releasenotes.txt}
%{_sbindir}/rc%{name}-init
%{_fillupdir}/sysconfig.%{name}-init
%attr(0755,root,root) %{_sbindir}/shorewall-init
%dir %{_datadir}/%{name}-init
%dir %{_libexecdir}/%{name}-init
%dir %attr(0755,root,root) %{_prefix}/lib//NetworkManager
%dir %attr(0755,root,root) %{_prefix}/lib//NetworkManager/dispatcher.d
%attr(0755,root,root) %{_prefix}/lib/NetworkManager/dispatcher.d/01-%{name}
%{_datadir}/%{name}-init/version
%attr(0544,root,root) %{_libexecdir}/%{name}-init/ifupdown
%dir %{_sysconfdir}/sysconfig/network
%dir %{_sysconfdir}/sysconfig/network/if-down.d
%attr(0544,root,root) %{_sysconfdir}/sysconfig/network/if-down.d/%{name}
%dir %{_sysconfdir}/sysconfig/network/if-up.d
%attr(0755,root,root) %{_sysconfdir}/sysconfig/network/if-up.d/%{name}
%{_mandir}/man8/%{name}-init.8*
%dir %{_distconfdir}
%dir %{_distconfdir}/logrotate.d/
%{_distconfdir}/logrotate.d/%{name}-init
%attr(644,root,root) %{_unitdir}/%{name}-init.service

%files core
%defattr(-,root,root,-)
%doc shorewall-core-%{version}/{COPYING,changelog.txt,releasenotes.txt}
%{_sbindir}/%{name}
%dir %{_datadir}/shorewall/
%{_datadir}/shorewall/coreversion
%{_datadir}/shorewall/functions
%{_datadir}/shorewall/lib.cli
%{_datadir}/shorewall/lib.cli-std
%{_datadir}/shorewall/lib.common
%{_datadir}/shorewall/lib.core
%{_datadir}/shorewall/lib.runtime
%dir %{_libexecdir}/shorewall
%{_libexecdir}/shorewall/wait4ifup
%{_datadir}/shorewall/shorewallrc

%files docs
%defattr(-,root,root,-)
%doc %{name}-docs-html-%version/*
%doc %{name}-%version/{Contrib,Samples}

%changelog
* Mon Feb 26 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Thu Jun 15 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Fix parameters to systemd_postun: this macro still takes the
  service names as parameters.
* Thu Dec  8 2022 Thorsten Kukuk <kukuk@suse.com>
- Add /etc/sysconfig/network hierachy, as this don't exist by
  default anymore
* Sat Sep  3 2022 Bruno Friedmann <bruno@ioda-net.ch>
- Add %%dir %%{_distconfdir} stop build failing on Leap
* Thu Sep  1 2022 Bruno Friedmann <bruno@ioda-net.ch>
- **Warning** this is the last patch revision to shorewall.
  No migration to manage nft will happen upstream.
  Be prepared to package removal, and migrate to firewalld.
- Add shorewall-fix-install-manpages.patch fix boo#1203006
- Update spec copyright and macros
- Move /etc to /usr for Networkmanager and logrotate
- Update rpmlint check list
* Mon Nov  9 2020 Bruno Friedmann <bruno@ioda-net.ch>
- Rework xt_geo_ip fixes by using dynamic patching with find
  which is less burden and confusing than manual patches series.
- Add dynamic patching for *.service with removing like upstream
  the obsolete StandardOutput=syslog until new release
* Sun Nov  8 2020 Togan Muftuoglu <toganm@opensuse.org>
- Correct the xt_geo_ip locations
- Correct output to journal
* Sat Sep 26 2020 Bruno Friedmann <bruno@ioda-net.ch>
- Update to version 5.2.8 (Upgrade your configuration)
  https://shorewall.org/pub/shorewall/5.2/shorewall-5.2.8/releasenotes.txt
  + Certain restrictions that apply to wildcard interfaces (interface
    name ends in '+') were previously not enforced when the logical
    interface name did not end in '+' but the physical interface name
    did end in '+'.  That has been corrected.
  + To ensure that error messages appear in the correct place in the
    output stream, stderr is now redirected to stdout when the
    configured PAGER is used by a command.
  + Since Shorewall 5.1.0, the Shorewall uninstall.sh script has
    incorrectly removed ${SBINDIR}/shorewall, while the Shorewall-core
    uninstall.sh script has failed to remove that file. Both scripts
    have been corrected.
  + Previously, the Shorewall CLI included a spurious hyphen ('-')
    between the product name (e.g., 'Shorewall6') and the version when
    printing a command output banner.
  + The shorewall-snat(5) manpage previously stated that a
    comma-separated list of IP address could be specified for
    SNAT. That statement was in error and has been removed. As part of
    this change, IPv4 Example 6 has been updated to use the
    PROBABILITY column.
  - New features
    + 'show tc' command now shows the classifiers associated with
    each interface (as displayed by the 'show classifiers'
    command). This integrated qdisc/filter information is also included
    in the output of the 'dump' command. This change deprecates the
    'show classifiers' ('show filters') command, as that command's
    output is now included in the 'show tc' output.
    + Shorewall6 has traditionally generated rules for IPv6 anycast
    addresses. These rules include:
    a)  Packets with these destination IP addresses are dropped by
    REJECT rules.
    b)  Packets with these source IP addresses are dropped by the
    'nosmurfs' interface option and by the 'dropSmurfs' action.
    c)  Packets with these destination IP addresses are not logged
    during policy enforcement.
    d)  Packets with these destination IP addresses are processes by
    the 'Broadcast' action.
    Beginning with this release, individual network interfaces can be
    excluded from this treatment through use of the 'omitanycast'
    option in /etc/shorewall6/interfaces.
    Note: This option was named 'noanycast' in earlier Beta releases.
    + Duplicate function names have been eliminated between the
    Shorewall-core lib.cli shell library and the Shorewall lib.cli-std
    library.
    + The 'status' command in Shorewall[6]-lite now precedes the
    configuration directory name with the administrative host name
    separated with a colon (":").
    + Tuomo Soini has contributed a macro that handles NFS v1.4 (no
    dynamic ports).
- Packaging:
  + Add buildrequires for pkgconfig (missing)
  + Use macro for sbindir
* Sat Aug 22 2020 Bruno Friedmann <bruno@ioda-net.ch>
- Update to version 5.2.7
  + **Upgrade your configuration**
  https://shorewall.org/pub/shorewall/5.2/shorewall-5.2.7/releasenotes.txt
  + Previously, it was not possible to classify traffic by destination
    IP address when using an Intermediate Functional Block (IFB) for
    traffic shaping. This is because such classification takes place
    before the traffic passes through the mangle PREROUTING chain.
    Such filtering is now possible by setting the 'connmark' option in
    the tcdevices file. This option causes the current connection mark
    to be copied to the packet mark prior to filtering, thus allowing
    the packet mark to be used for classification.
    This change adds a new CONNMARK_ACTION capability which is
    required to be able to specify the 'connmark' option.
  + The tcpri file now supports ?FORMAT 2 which inserts an SPORT
    column directly to the right of the PORT column. As part of this
    change, the PORT column is renamed to DPORT while allowing both
    'port' and 'dport' to be used in the alternate input format. See
    shorewall-tcpri(5) and
    http://shorewall.org/simple_traffic_shaping.html for additional
    information.
  + The Simple TC document is now linked to FAQs 97 and 97a.
* Tue Jul  7 2020 Bruno Friedmann <bruno@ioda-net.ch>
- Update to version 5.2.6
  + **Upgrade your configuration**
  https://shorewall.org/pub/shorewall/5.2/shorewall-5.2.6/releasenotes.txt
  + When compiling for export, the compiler generates a firewall.conf
    file which is later installed on the remote firewall system as
    ${VARDIR}/firewall.conf. Previously, the CLI on that firewall was
    not processing the file, resulting in some features not being
    available:
  - Default values for VERBOSITY, LOGFILE, LOGFORMAT, PATH,
    SHOREWALL_SHELL, SUBSYSLOCK, RESTOREFILE, RESTART,
    DYNAMIC_BLACKLIST and PAGER are not supplied.
  - scfilter file supplied at compile time.
  - dumpfilter file supplied at compile time.
    That has been corrected.
  + A bug in iptables (see
    https://git.netfilter.org/iptables/commit/?id=d1555a0906e35ba8d170613d5a43da64e527dbe1)
    prevents the '--queue-cpu-fanout' option from being applied unless
    that option is the last one specified. Unfortunately, Shorewall
    places the '--queue-bypass' option last if that option is also
    specified.
    This release works around this issue by ensuring that the
    '--queue-cpu-fanout' option appears last.
  + The -D 'compile', 'check', 'reload' and 'Restart'  option was
    previously omitted from the output of 'shorewall help'. It is now
    included. As part of this change, an incorrect and conflicting
    description of the -D option was removed from the 'remote-restart'
    section of shorewall(8).
  + Previously, when EXPAND_POLICIES=No, chains that enforced ACCEPT
    policies were not completely optimized by optimize level 2 (ACCEPT
    rules preceding the final unconditional ACCEPT were not
    deleted). That has been corrected such that these rules are now
    optimized.
* Thu Jul  2 2020 Bruno Friedmann <bruno@ioda-net.ch>
- Update to version 5.2.5.2
  https://shorewall.org/pub/shorewall/5.2/shorewall-5.2.5/releasenotes.txt
  + 5.2.5.2
    Previously, ";;+" was mishandled in the snat file; the generated
    rule incorrectly included the leading "+". That has been corrected
    so that the generated rule is now correct.
    Example (SNAT OpenVPN server traffic leaving on eth0):
    SNAT(192.2.0.4)    -      eth0     ;;+ -p udp --sport 1194
  + 5.2.5.1
  - The change in 5.2.5 base which changed the 'user' facility to the
    'daemon' facility in Shorewall syslog messages did not change the
    messages with severity 'err'. That has been corrected such that
    all syslog messages now use the 'daemon' facility.
  - The actions.std file contains "?IF...?ELSE...?ENDIF" sequences
    that provide different action options depending on the availabilty
    of certain capabilities. This has resulted in the Broadcast and
    Multicast options being listed twice in the output of
    "shorewall[6] show actions". Beginning with this release, this
    duplication is eliminated. Note, however, that the options shown
    will be incomplete if they were continued onto another line, and
    may be incorrect for Broadcast and Multicast.
  - A typo in shorewall-providers(5) has been corrected.
  + 5.2.5 Base
  - Previously, Shorewall-init installed a 'shorewall' script in
    /etc/network/if-down.d on Debian and derivatives. This script was
    unnecessary and required Debian-specific code in the generated
    firewall script. The Shorewall-init script is no longer installed
    and the generated firewall script is now free of
    distribution-specific code.
  - Also on Debian and derivatives, Shorewall-init installed
    /etc//NetworkManager/dispatcher.d/01-shorewall which was also
    unnecessary.  Beginning with this release, that file is no longer
    installed.
  - Previously, if the dynamic-blacklisting default timeout was set in
    a variable in the params file and the variable was used in setting
    DYNAMIC_BLACKLIST, then the 'allow' command would fail with
    the message:
    ERROR: Invalid value (ipset-only,disconnect,timeout=) for
    DYNAMIC_BLACKLIST
    That has been corrected.
  - When EXPAND_POLICIES=No in shorewall[6].conf, policies in complex
    rulesets are enforced in chains such as 'net-all' and
    'all-all'. Previously, these chains included redundant
    state-oriented rules. In addition to being redundant. these rules
    could actually break complex IPv6 configurations. The extra rules are
    now omitted.
* Tue May 26 2020 Bruno Friedmann <bruno@ioda-net.ch>
- Update to bugfix version 5.2.4.5
  + The description of the 'optional' option has been expanded in
    shorewall-interfaces(5).
  + Previously, the AUTOMAKE option did not work properly when
    /etc/shorewall[6] was a symbolic link. That has been corrected.
- Packaging
  + Remove broken %%pretrans, move content to %%pre
  + Remove use of %%release in rpm scriptlet
  + This will avoid constant rebuild.
* Thu Apr 30 2020 Bruno Friedmann <bruno@ioda-net.ch>
- Update to bugfix version 5.2.4.4
  + When DYNAMIC_BLACKLIST=ipset... or when SAVE_IPSETS=Yes in
    shorewall[6].conf, 'shorewall[6] start' could hang. Fixed.
  + 'shorewall[6] start' would not automatically create dynamic
    blacklisting ipsets. That has been corrected.
- This version will served also as maintenance upgrade for Leap
* Wed Apr 22 2020 Bruno Friedmann <bruno@ioda-net.ch>
- Update to version 5.2.4.2
  https://shorewall.org/pub/shorewall/5.2/shorewall-5.2.4/releasenotes.txt
  + Fixes for debian
- Update to version 5.2.4.1
  + Fixes for openSUSE shorewall-init
  will now ignore 'start' and 'stop' commands, for running firewalls
  + Spurious messages have been removed
- Packaging
  + Move /usr/sbin/shorewall to shorewall-core so -lite version
    doesn't need main shorewall package
  + To make shorewall remote-* command working we patch lib.cli-std
    to use /usr/sbin instead of /sbin + commented spec
  + Desactivate for the moment the upgrade warning. we need to
    find a 100%% working solution.
  + use %%{var} form everywhere
* Tue Apr 14 2020 Bruno Friedmann <bruno@ioda-net.ch>
- Add perl-base as buildrequirement to force choice of SHA-DIGEST
  new problem in TW
- To fix boo#1166114 never restart shorewall-init.service
  macro service_del_postun is replaced by simplier systemd_postun
- Remove conflict between main and lite package.
  A managing station need main to build configuration and can use
  - lite to execute it. Users are in charge of choosing which
  service has to be started and used. ❤ Freedom
* Sat Apr  4 2020 Bruno Friedmann <bruno@ioda-net.ch>
- Remove shorewall require from shorewall-init (was a forgoten
  action)
* Tue Mar 31 2020 Bruno Friedmann <bruno@ioda-net.ch>
- Update to version 5.2.4
  https://shorewall.org/pub/shorewall/5.2/shorewall-5.2.4/releasenotes.txt
  + Previously, when a Shorewall6 firewall was placed into the
    'stopped' state, ICMP6 packets required by RFC 4890 were not
    automatically accepted by the generated ruleset.
    Beginning with this release, those packets are automatically
    accepted.
  + Previously, the output of 'shorewall[6] help' displayed the
    superseded 'load' command. That text has been deleted.
  + The QOSExample.html file in the documentation and on the web site
    previously showed tcrules content for the /etc/shorewall/mangle
    file (recall that 'mangle' superseded 'tcrules'). That page has
    been corrected.
  + The 'Starting and Stopping' and 'Configuration file basics'
    documents have been updated to align them with the current product
    behavior.
  +  The 'ipsets' document has been updated to clarify the use of
    ipsets in the stoppedrules file.
- Packaging
  + shorewall-init package has a removed %%service_del_postun
    macro to close bug boo#1166114 Restarting this service can
    lock down admin out of the system.
  + shorewall(6) and shorewall(6)-lite conflict has they shouldn't
    be installed together on the same system.
  + conf_update flag is set to 1 to activate update reminder
  + Adjust and cleanup requires
* Sun Mar 15 2020 Bruno Friedmann <bruno@ioda-net.ch>
- Add version to requires in -lite version
* Wed Mar 11 2020 Bruno Friedmann <bruno@ioda-net.ch>
- Update to minor bugfix version 5.2.3.7
  + When DOCKER=Yes, if both the DOCKER-ISOLATE and
    DOCKER-ISOLATE-STAGE-1 existed then the DOCKER-ISOLATE-STAGE-*
    chains were not preserved through shorewall state changes.
    That has been corrected so that both chains are preserved if
    present.
  + Previously, the compiler always detected the OLD_CONNTRACK_MATCH
    capability as being available in IPv6. When OLD_CONNTRACK_MATCH
    was available, the compiler also mishandled inversion ('!') in the
    ORIGDEST columns, leading to an assertion failure.
    Both the incorrect capability detection and the mishandled
    inversion have been corrected.
  + During 'enable' processing, if address variables associated with
    the interface have values different than those when the firewall
    was last started/restarted/reloaded, then a 'reload' is performed
    rather than a simple 'enable'. The logic that checks for those
    changes was incorrect in some configurations, leading to unneeded
    reload operations. That has been corrected.
  + When MANGLE_ENABLED=No in shorewall[6].conf, some features
    requiring use of the mangle table can be allowed, even though the
    mangle table is not updated. That has been corrected such that use
    of such features will raise an error.
  + When the IfEvent(...,reset) action was invoked, the compiler
    previously emitted a spurious "Resetting..." message. That message
    has been suppressed.
- Packaging
  + Do not provide anymore unsused notrack file
  + Introduce define conf_need_update to track when we activate the
  post update warning for users when there's minor or major version
  update of shorewall bnc#1166114
* Mon Feb 17 2020 Bruno Friedmann <bruno@ioda-net.ch>
- Update to bugfix minor 5.2.3.6
  + Fix for possible start failure when both Docker containers
    and Libvirt VMs were in use.
* Mon Feb  3 2020 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire pkgconfig(systemd) instead of systemd: allow OBS to
  shortcut through the -mini flavors.
* Thu Jan 23 2020 Bruno Friedmann <bruno@ioda-net.ch>
- Update to bugfix minor 5.2.3.5
  + A typo in the FTP documentation has been corrected.
  + The recommended mss setting when using IPSec with ipcomp
    has been corrected.
  + A number of incorrect links in the manpages have been
    corrected.
  + The 'bypass' option is now allowed when specifying an
    NFQUEUE policy. Previously, specifying that option resulted
    in an error.
  + Corrected IPv6 Address Range parsing.
  + Previously, such ranges were required to be of the form
    [<addr1>-<addr2>] rather than the more standard form
    [<addr1>]-[<addr2>]. In the snat file (and in nat actions),
    the latter form was actually flagged as an error while in
    other contexts, it resulted in a less obvious error being
    raised.
  + The manpages have been updated to refer to
    https://shorewall.org rather than http://www.shorewall.org.
- Refresh spec file
* Wed Sep  4 2019 Bruno Friedmann <bruno@ioda-net.ch>
- Update to bugfix minor 5.2.3.4
  + Update release documents.
  + Correct handling of multi-queue NFQUEUE as a policy.
  + Correct handling of multi-queue NFQUEUE as a macro parameter.
  + Make 'AUTOMAKE=No' the update default.
  + Correct the description of the 'bypass' NFQUEUE option in
    shorewall-rules(5).
* Mon Apr 15 2019 Bruno Friedmann <bruno@ioda-net.ch>
- Update to bugfix minor 5.2.3.3
  Previously, if an ipset was specified in an SPORT column, the
  compiler would raise an error similar to:
  ERROR: Invalid ipset name () /etc/shorewall/rules (line 44)
- Update to bugfix minor 5.2.3.2
  Shorewall 5.2 automatically converts an existing 'masq' file to an
  equivalent 'snat' file. Regrettably, Shorewall 5.2.3 broke that
  automatic update, such that the following error message was issued:
  Use of uninitialized value $Shorewall::Nat::raw::currentline in
  pattern match (m//) at /usr/share/shorewall/Shorewall/Nat.pm
  line 511, <$currentfile> line nnn. and the generated 'masq'
  file contains only initial comments. That has been corrected.
* Wed Feb 27 2019 Bruno Friedmann <bruno@ioda-net.ch>
- Update to bugfix minor 5.2.3.1 release
  + An issue in the implementation of policy file zone exclusion,
    released in 5.2.3 has been resolved. In the original release,
    if more than one zone was excluded then the following error was
    raised:
    ERROR: 'all' is not allowed in a source zone list
    etc/shorewall/policy (line ...)
* Sat Feb 23 2019 Bruno Friedmann <bruno@ioda-net.ch>
- Update to new 5.2.3 bugfix release
  http://www.shorewall.net/pub/shorewall/5.2/shorewall-5.2.3/releasenotes.txt
  This is the retirement of Tom Eastep see.
  https://sourceforge.net/p/shorewall/mailman/message/36589782/
- Removed module* in file section
- Clean-up changes and spec (trailing slashes)
* Sun Feb  3 2019 Bruno Friedmann <bruno@ioda-net.ch>
- Update to new 5.2.2 bugfix release
  http://www.shorewall.net/pub/shorewall/5.2/shorewall-5.2.2/releasenotes.txt
- Packaging:
  + As seen with upstream recommend running shorewall update on
    all version update
  + to be done: run update automatically
* Fri Jan  4 2019 Bruno Friedmann <bruno@ioda-net.ch>
- Update to major version 5.2.1.4
  A lot of changes occurs since last package please consult
  http://www.shorewall.net/pub/shorewall/5.2/shorewall-5.2.1/releasenotes.txt
  and the know problem list at
  http://www.shorewall.net/pub/shorewall/5.2/shorewall-5.2.1/known_problems.txt
- Update your configuration shorewall update
- Packaging: renew spec file with spec-cleaner
* Sun Apr 15 2018 bruno@ioda-net.ch
- Changes in 5.1.12.3
  Problems Corrected:
  When 'reset' and 'dst' were specified to the IfEvent action,
  the action would incorrectly attempt to reset the event for the
  SOURCE IP address rather than the DEST address. That has been
  corrected.
* Mon Mar  5 2018 bruno@ioda-net.ch
- spec :
  + Minimal changes with spec-cleaner
  + Stop conflicting with other firewall (SuSEFirewall2, firewalld)
    User can have several management tools, and it help preparing
    a migration
- Run shorewall(6) update -A to update your configurations
  Check and adapt them before restarting.
- Changes in 5.1.12.3
  + Update release documents.
  + Ensure that mutex gets released at exit.
- Changes in 5.1.12.2
  + Alter documentation to prefer ';;' over ';' in INLINE and
    IP[6]TABLES rules.
  + Make 'update' convert ';' to ';;' in INLINE, IPTABLES and
    IP6TABLES rules.
  + Correct typo that resulted in an "unknown function" Perl
    diagnostic.
  + Correct "Invalid policy" message.
  + Fix omitted SYN limiting.
- Changes in 5.1.12.1
  + Replace macro.SSDPServer with corrected macro.SSDPserver.
- Changes in 5.1.12 Final
  + Update release documents.
  + Add INLINE_MATCHES=Yes to the deprecated list.
- Changes in 5.1.12 RC 1
  + Update release documents.
  + Minor performance enhancements to Optimize Category 8.
  + Always report IPSET_MATCH.
- Changes in 5.1.12 Beta 2
  + Delete undocumented OPTIMIZE_USE_FIRST option.
  + Merge 5.1.11.
  + Suppress trailing whitespace.
  + Avoid awkward blank lines.
- Changes in 5.1.12 Beta 1
  + Code and manpage cleanup.
  + Allow SNAT in the INPUT chain.
- Changes in 5.1.11 Final
  + Update release documents.
- Changes in 5.1.11 RC 1
  + Update versions and copyrights.
  + Clear the connection mark on forwarded IPSEC tunneled connections
  + Make TRACK_PROVIDERS=Yes the default.
- Changes in 5.1.11 Beta 2
  + Be selective about verification of the conntrack utility when
  + DYNAMIC_BLACKLIST=ipset,disconnect...
  + Don't require shorewall to be started for 'allow' with
    ipset-based DBL.
  + Make address variables play nice with the 'clear' command.
  + Don't unconditionally enable forwarding during 'clear'.
- Changes in 5.1.11 Beta 1
  + Allow non-root to run some 'show' commands.
  + Use synchain name in log messages rather than base chain name.
  + Assume :syn for TCP CT entries in the conntrack file and HELPER.
  + Limit depth of 'find' search when AUTOMAKE=Yes.
- Changes in 5.1.10.2
  + Limit 'find' to depth 1.
  + Don't run find in an empty entry in $CONFIG_PATH
- Changes in 5.1.10.1
  + Fix Shorewall-core installer for sandbox case.
  + Make /etc and /configfiles the same.
- Changes in 5.1.10 Final
  + Add warning re wildcard and OPTIONS.
  + Correct IPv6 Universal interfaces file.
- Changes in 5.1.10 RC 1
  + Correct ingress policing.
  + Fix Shorewall-init recompilation problem.
- Changes in 5.1.10 Beta 2
  + Allow a protocol to be associated with a regular action.
  + Remove the PSH flag from the FIN action.
- Changes in 5.1.10 Beta 1
  + Allow CONFIG_PATH setting to begin with ':' to allow dropping
    the first directory by non-root.
  + Correct several typos in the manpages (Roberto Sánchez).
  + Correct typo in 'dump' processing.
  + Reset all table counters during 'reset'.
- Changes in 5.1.9 Final
  + Use logical interface names in the Sample configs.
- Changes in 5.1.9 RC 1
  + Apply W Van den Akker's OpenWRT/Lede patches.
  + Don't verify IP and SHOREWALL_SHELL paths when compiling for
    export.
  + Support for Redfish remote console in macro.IPMI
- Changes in 5.1.9 Beta 2
  + Merge content from 5.1.8.
- Changes in 5.1.9 Beta 1
  + Update release documents.
  + Add TCPMSS action in the mangle file.
  + Inline the Broadcast action when ADDRTYPE match is available.
  + Support logging in the snat file.
  + Add shorewall-logging(5).
- Changes in 5.1.8 Final
  + Correct 'delete_default_routes()'.
  + Delete default routes from 'main' when a fallback provider is
    successfully enabled.
  + Don't restore default route when a fallback provider is enabled.
  + Issue a warning when 'persistent' is used with
    RESTORE_DEFAULT_ROUTE=Yes.
  + Don't dump SPD entries for the other address family.
  + Fix 'persistent' provider issues.
  + Treat LOG_TARGET the same as all other capabilities.
  + Allow merging of rules with IPSEC policies
* Sun Nov 12 2017 bruno@ioda-net.ch
- spec :
  + use new %%_fillupdir macro with env DIRFILLUP in build
  * Redone patches *-fillup-install.patch to use ${DIRFILLUP}
  * use new %%_fillupdir macro in files
  + change require perl to perl-base
  + Added conflict with firewalld
  + Refresh list of files and modules
- Run shorewall(6) update -A to update your configurations
  Check and adapt them before restarting.
- 5.1.8.1 release - Recommended action :
  + Update release documents
  + Make persistent routes and rules independent of 'autosrc'
  + Correct 'delete_default_routes()'
  + Delete default routes from 'main' when a fallback provider is
    successfully enabled
  + Don't restore default route when a fallback provider is enabled
  + Issue a warning when 'persistent' is used with
    RESTORE_DEFAULT_ROUTE=Yes
  + Don't dump SPD entries for the other address family
  + Fix 'persistent' provider issues
  + Treat LOG_TARGET the same as all other capabilities
  + Allow merging of rules with IPSEC policies
- 5.1.7.2 release
  Please refer to releasenote.txt for a detailled description.
  As always use shorewall [-6] update and revise your configuration
  + Features summary
  * Module loading streamlined, shorewall [-6] update will remove
    MODULE_SUFFIX configuration
  * Check route if detect is used in gateway column (dhcpd5 has
    now binary encoded .lease)
  * DNAT and REDIRECT support in ShorewallActions
  * Docker configuration support: DOCKER-INGRESS chain.
  + Fixes summary
  * Fix shorewall-snat(5) man page example, DEST column has to be
    read eth0:+myset[dst]
  * Fix invalid vlsm to ipcalc message
  * ADD_IP_ALIASES is set to NO for ipv6 while yes for ipv4
  * Cleanup .tmp in save ipset operations.
  * Command reenable fix for persistent and non-persistent
    interfaces
  * Warn if getattr failed (SeLinux)
- 5.1.6 release
  + Fixes summary
  * $SHAREDIR $CONFIGDIR available again
  * Fix compilation with optimize level 8
  * Be consistant with Netfilter interpretation of 'eth'='eth+'
  * RESTORE_WAIT_OPTION serialize start of ipv4/ipv6 with -w option
  * RDP macros handle also UDP part
  + Features summary
  * Sparse option (not implemented in our spec)
  * Add enable / disable runtime extension script
  * Check zone and subzone to share at least one interface
  * Runtime address and port variables
  * Iptables --wait option used for serialization
* Tue Aug 15 2017 bruno@ioda-net.ch
- Update to bugfix release 5.1.5.2
  + Make build reproducible boo#1047218
  + Fix upgrade from 4x version : dropBcast and dropBcasts are now
    supported boo#1053650
  + Perl 5.26 support
  + Fix for BASIC_FILTERS=Yes and tcfilters
  + Fix USER/GROUP messages
  + MAC address in OUTPUT col in accounting file error is raised
    at compile time
  + Fix port number 0 or > 65535 perl execption
* Sat Aug 12 2017 olaf@aepfle.de
- Update filename in /var/adm/update-messages to match documentation,
  and build-compare pattern
* Wed Jul 12 2017 bruno@ioda-net.ch
- bugfix release 5.1.4.4
  A defect in 5.1.4.3 caused a startup failure when two or more
  'fallback' providers were configured. That has been corrected.
* Thu Jun 29 2017 alarrosa@suse.com
- Fix a typo in %%posttrans that would remove the wrong file and could
  cause a problem depending on the execution order of the %%pretrans
  and %%posttrans scripts for the shorewall and shorewall6 packages.
* Wed Jun 21 2017 bruno@ioda-net.ch
- This stable branch 5.1x will be the new default for Leap 42.3.
  Remember that each time you have an upgrade with changes in Major
  or Major,Minor it is mandatory you upgrade your configuration
  with shorewall(6) update -a /etc/shorewall(6) command.
- Packaging : use pretrans and posttrans to inform user about
  configuration upgrade.
- Bugfix release 5.1.4.3. Problem Corrected:
  When running on prior-generation distributions such as RHEL6,
  IPv6 multi-ISP configurations failed to start due to an error
  such as the following:
  ERROR: Command "ip -6 -6 route replace default scope global
    table 250 nexthop via ::192.88.99.1 dev tun6to4 weight 1"
    Failed
  Such configurations now start successfully.
* Wed Jun 14 2017 bruno@ioda-net.ch
- Bugfix and enhancement release 5.1.4.2
  complete changelog is available
  http://shorewall.net/pub/shorewall/5.1/shorewall-5.1.4/releasenotes.txt
- Main changes
  All IPv6 standard actions have been deleted and their logic
  has been added to their IPv4 counterparts who can now handle
  both address families.
  Previously, ?error and ?require messages as well as verbose ?info
  and ?warning messages (those that report the file and line numbers)
  generated from an action file would report the action file name and
  line number rather than the file and line number where the action
  was invoked. The file and line number where the action was invoked
  were listed second. Beginning with this release, the invoking file
  and line number are listed first and the action file and line number
  are not reported. This allows for creation of clearer messages.
  IPv6 UPnP support (including MINIUPNPD) is now available.
  A PERL_HASH_SEED option has been added to allow the Perl hash seed
  to be specified.  See shorewall.conf(5) and perlsec(1) for details.
* Sat Mar 25 2017 bruno@ioda-net.ch
- Bugfix release 5.1.3.2
  Previously, if a Shorewall Variable (e.g., @chain) was the target
  of a conditional ?RESET directive (one that was enclosed in ?if.
  ?else...?endif logic), the compiler could incorrectly use an
  existing chain created from the action rather than creating a new
  (and different) chain. That has been corrected.
  Previously, if alternate input format specified a column that had
  already been specified, the contents of that column were silently
  overwritten. Now, a warning message is issued stating that the
  prior value has been replaced by the newer value.
* Sun Mar 19 2017 bruno@ioda-net.ch
- Update to last bugfix version 5.1.3.1
  Problems Corrected:
  There was a typo in the BLACKLIST_DEFAULT settings in the 5.1.3
  sample config files, which resulted in a compilation error.
  That typo has been corrected.
  There was also a typo in the two-interface IPv4 sample snat file;
  192.168.0.0/16 was inadvertently entered as 92.168.0.0/16. That has
  been corrected.
  Previously, when processing the policy file, 'all+' was incorrectly
  treated the same as 'all'. That has been corrected so that 'all+'
  causes intra-zone traffic to be included in the policy.
* Wed Mar 15 2017 bruno@ioda-net.ch
- Upgrade to last stable 5.1.3
  For details see changelog.txt and releasenotes.txt containing all
  informations for a correct upgrade path.
- Packaging Redone patches for var-fillup
  + shorewall-fillup-install.patch
  + shorewall-init-fillup-install.patch
  + shorewall-lite-fillup-install.patch
* Sun Feb 12 2017 bruno@ioda-net.ch
- Upgrade to stable 5.1.1
  For details see changelog.txt and releasenotes.txt containing all
  informations for a correct upgrade path.
- Packaging:
  + use proper %%{} syntax
  + Adjust year copyright
  + Remove attr on sbindir symlink
  + Move Samples and Contrib to doc package
* Wed Dec  7 2016 bruno@ioda-net.ch
- Upgrade to last stable of 5.0.x version 5.0.15
  For details see changelog.txt and releasenotes.txt containing all
  informations for a correct upgrade path.
- Packaging :
  + Remove all non suse %%if
  + Cleanup older non supported version
  + Remove upstream merged patch
  * 0001-remote_fs.patch
  * 0001-required-stop-fix.patch
  + Remove 0001-fillup-install.patch replaced by specific product
    patch for correct usage of var-fillup
  + Added patches for var-fillup when not specific %%name6 is also
    supported
  * shorewall-fillup-install.patch
  * shorewall-init-fillup-install.patch
  * shorewall-lite-fillup-install.patch
  + spec-cleaner minimal
* Sun Mar  6 2016 bruno@ioda-net.ch
- Update to last 4x bugfix version 4.6.13.4
  For details see changelog.txt and releasenotes.txt
  - 4.6.13.4
  * This release includes a couple of additional configure/install
    fixes from Matt Darfeuille.
  * The DROP command was previously rejected in the mangle file.
  That has been corrected.
  - 4.6.13.3
  * Previously, Shorewall6 rejected rules in which the SOURCE
  contained both an interface name and a MAC address (in
  Shorewall format). That defect has been corrected so that such
  rules are now accepted.
  * A number of corrections have been made to the install,
  uninstall and configure scripts (Matt Darfeuille).
  * Previously, optional interfaces were not enabled during 'start'
  and 'restart' unless there was at least one entry in the
  'providers' file.  This resulted in these interfaces not
  appearing in the output of 'shorewall[6] status -i'.
  * The check for use of a circular kernel log buffer (as opposed
  to a log file) has been improved.
  * Previously, if a circular log buffer was being used, the output
  of various commands still displayed '/var/log/messages' as the
  log file. Now, it is displayed as 'logread'.
  * When processing the 'dump' command, the CLI now uses 'netstat'
  to print socket information when the 'ss' utility is not
  installed.
  - 4.6.13.2
  * Previously, if statistical load balancing was used in the
  providers file, the default route in the main table was not
  deleted during firewall start/restart. That route is now
  correctly deleted.
  - 4.6.13.1
  * Previously, the 'reset' command would fail if chain names were
    included. Now, the command succeeds, provided that all of the
    specified chains exist in the filter table.
  * The TCP meta-connection is now supported by the Tinc macro and
    tunnel type. Previously, only the UDP data connection was
    supported.
* Tue Sep 15 2015 toganm@opensuse.org
- Update to version 4.6.13 For more details see changelog.txt and
  realeasenotes.txt
  * The 'rules' file manpages have been corrected regarding the
    packets that are processed by rules in the NEW section.
  * Parsing of IPv6 address ranges has been corrected. Previously,
    use of ranges resulted in 'Invalid IPv6 Address' errors.
  * The shorewall6-hosts man page has been corrected to show the
    proper contents of the HOST(S) column.
  * Previously, INLINE statements in the mangle file were not
    recognized if a chain designator (:F, :P, etc.) followingowed
    INLINE(...). As a consequence, additional matches following
    a semicolon were interpreted as column/value pairs unless
    INLINE_MATCHES=Yes, resulting in compilation failure.
  * Inline matches on IP[6]TABLE rules could be ignored if
    INLINE_MATCHES=No. They are now recognized.
  * Specifying an action with a logging level in one of the
    _DEFAULT options in shorewall[6].conf
    (e.g., REJECT_DEFAULT=Reject:info) produced a compilation error:
    ERROR: Invalid value (:info) for first Reject parameter
    /usr/share/shorewall/action.Rejectect (line 52)
    That has been corrected. Note, however, that specifying logging
    with a default action tends to defeat one of the main purposes
    of default actions which is to suppress logging.
  * Previously, it was necessary to set TC_EXPERT=Yes to have full
    access to the user mark in fw marks. That has been corrected so
    that any place that a mark or mask can be specified, both the
    TC mark and the User mark are accessible.
* Tue Jul 14 2015 toganm@opensuse.org
- Update to version 4.6.11 For more details see changelog.txt and
  releasenotes.txt
  * Previously, when the -c option was given to the 'compile'
    command, the progress message "Compiling..." was issued before
    it was determined if compilation was necessary.  Now, that message
    is suppressed when re-compilation is not required.
  * Previously, when the -c option was given to the 'compile'
    command, the 'postcompile' extension script was executed even when
    there was no (re-)compilation. Now, the 'postcompile' script is
    only invoked  when a new script is generated.
  * If CONFDIR was other than /etc, then ordinary users would not
    receive a clear error message when they attempted to execute
    one of the commands that change the firewall state.
  * Previously, IPv4 DHCP client broadcasts were blocked by the
    'rpfilter' interface option. That has been corrected.
  * The 'update' command incorrectly added the INLINE_MATCHES
    option to shorewall6.conf with a default value of 'Yes'. This
    caused 'start' to fail with invalid ip6tables rules when the alternate
    input format using ';' is used.
    Note: This last issue is not documented in the release notes
    included with the release.
* Wed Jun 17 2015 toganm@opensuse.org
- Update to version 4.6.10.1 For more details see changelog.txt and
  releasenotes.txt
  * Indentation is now consistent in lib.core (Tuomo Soini).
  * The first problem corrected in 4.6.10 below was incomplete. It
    is now complete (Tuomo Soini).
  * Similarly, the second fix was also incomplete and is now
    completed  (Tuomo Soini).
* Thu May  7 2015 toganm@opensuse.org
- Update to version 4.6.9 For more details see changelog.txt and
  releasenotes.txt
  * This release contains defect repair from Shorewall 4.6.8.1 and
    earlier releases.
  * The means for preventing loading of helper modules has been
    clarified in the documentation.
  * The SetEvent and ResetEvent actions previously set/reset the
    event even if the packet did not match the other specified
    columns. This has been corrected.
  * Previously, the 'show capabilities' command was ignoring the
    HELPERS setting. This resulted in unwanted modules being
    autoloaded  and, when the -f option was given, an incorrect
    capabilities file was generated.
  * Previously, when 'wait' was specified for an interface, the
    generated script erroneously checked for required interfaces on
    all commands rather than just start, restart and restore.
* Tue Apr 14 2015 toganm@opensuse.org
- Update to version 4.6.8.1 For more details see changnlog.txt and
  releasenotes.txt
  * Previously, when servicd was installed and there were one or
    more required interfaces, the firewall would fail to start at
    boot.This has been corrected by Tuomo Soini.
  * Some startup logic in lib.cli has been deleted. A bug prevented
    the code from working as intended, so there is no loss of
    functionality resulting from deletion of the code.
* Sat Apr  4 2015 toganm@opensuse.org
- Update to version 4.6.8 For more details see changelog.txt and
  releasenotes.txt
  * This release includes defect repair from Shorewall 4.6.6.2 and
    earlier releases.
  * Previously, when the -n option was specified and NetworkManager
    was installed on the target system, the Shorewall-init installer
    would still create
    ${DESTDIR}etc/NetworkManager/dispatcher.d/01-shorewall, regardless
    of the setting of $CONFDIR. That has been corrected such that
    the directory
    ${DESTDIR}${CONFDIR}/NetworkManager/dispatcher.d/01-shorewall
    is created instead.
  * Previously, handling of the IPTABLES and IP6TABLES actions in
    the conntrack file was broken. nfw provided a fix on IRC.
  * The Shorewall-core and Shorewall6 installers would previously
    report incorrectly that the product release was not installed.
    Matt Darfeuille provided fixes.
* Fri Mar 13 2015 toganm@opensuse.org
- Update to version 4.6.7 For more details see changelog.txt and
  releasenotes.txt
  * This release includes defect repair from Shorewall 4.6.6.2 and
    earlier releases.
  * The 'tunnels' file now supports 'tinc' tunnels.
  * Previously, the SAME action in the mangle file had a fixed
    timeout of 300 seconds (5 minutes). That action now allows
    specification of a different timeout.
  * It is now possible to add or delete addresses from an ipset
    with entries in the mangle file. The ADD and DEL actions have
    the same behavior in the mangle file as they do in the rules
    file.
- Added systemd_version macro in anticipation of detecting the
  correct service file when systemd version is >= 214
* Sat Feb  7 2015 toganm@opensuse.org
- Update to version 4.6.6.2 For more details see changelog.txt and
  releasenotes.txt
  * The compiler failed to parse the construct +<ipset>[n] where n is
    an integer (e.g., +bad[2]).
  * Orion Paplawski has provided a patch that adds 'ko.xz' to the
    default MODULE_SUFFIX setting. This change deals with recent
    Fedora releases where the module names now end with ".ko.xz".
    In addition to Orion's patch, the sample configurations have
    been modified to specify MODULE_SUFFIX="ko ko.xz".
* Sat Jan 24 2015 toganm@opensuse.org
- Update to version 4.6.6.1 For more details see changelog.txt and
  releasenotes.txt
  * Previously the SAVE and RESTORE actions were erroneously disallowed
    in the INPUT chain within the mangle file.
  * The manpage descriptions of the mangle SAVE and RESTORE actions
    incorrectly required a slash (/) prior to the mask value.
  * Race conditions could previously occur between the 'start'
    command and the 'enable' and 'disable' commands.
  * The 'update' command incorrectly added the INLINE_MATCHES
    option to shorewall.conf with a default value of 'Yes'. This
    caused 'start' to fail with invalid iptables rules when the
    alternate input format using ';' is used.
  * Previously the LOCKFILE setting was not propagated to the
    generated script. So when the script was run directly, the script
    unconditionally used ${VARDIR}/lock.
* Sat Jan 17 2015 toganm@opensuse.org
- Update to version 4.6.6 For more details see changlelog.txt and
  releasenotes.txt As there are many new features with this release
  please consult the mentioned files.
  * Previously, a line beginning with 'shell' was interpreted as a
    shell script. Now, the line must begin with 'SHELL'
    (case-sensitive).
    Note that ?SHELL and BEGIN SHELL are still case-insensitive.
* Mon Jan 12 2015 toganm@opensuse.org
- Update to version 4.6.5.5 For more details see changelog.txt and
  releasenotes.txt
  * This release adds Tuomo Soini's fix for Shorewall-init to 4.6.5.5.
    Previously, the ifupdown scripts were looking in the wrong
    directory for the firewall script.
* Sat Jan 10 2015 toganm@opensuse.org
- Update to version 4.6.5.4 For more details see changelog.txt and
  releasenotes.txt
  * The '-c' option of the 'dump' and 'show routing' commands is
    now documented.
  * The handling of the 'DIGEST' environmental variable has been
    corrected in the Shorewall installer. Previously, specifying
    that option would not correctly update the Chains module which
    led to a Perl compilation failure.
  * Handling of ipset names in PORT columns has been corrected.
    Previously, such usage resulted in an invalid  iptables rule
    being generated.
* Thu Dec 18 2014 toganm@opensuse.org
- Update to version 4.6.5.3 For more details see changelog.txt and
  releasenotes.txt
  * The Shorewall-init scripts were using the incorrect
    variable to set the state directory. Correction provided by
    Roberto Sanchez.
  * For normal dynamic zones, the 'add' command failed with a
    diagnostic such as:
    ERROR: Zone ast, interface net0 does not have a dynamic host
    list
  * When a mark range was used in the marks (tcrules) file, a
    run-time error occurred while attempting to load the generated
    ruleset.
* Thu Dec 11 2014 dimstar@opensuse.org
- Do not buildrequire openSUSE-release: it's a daily changing
  package and causes thus frequent rebuilds for no reason.
  configure and install both try to guess the target from
  /etc/os-release. So we simply inject BUILD=suse for the openSUSE
  case.
* Sun Nov 23 2014 toganm@opensuse.org
- Update to version 4.6.5.2 For more details see changelog.txt and
  releasenotes.txt
  * LOG_BACKEND=LOG failed at run-time for all but the most recent
    kernels.
- Changes in 4.6.5.1
  * The generated script can now detect an gateway address assigned
    by later versions of that program (Alan Barrett).
  * In 4.6.5, the bash-based configure script would issue the
    following diagnostic if SERVICEDIR was not specified in the
    shorewallrc file:
    ./configure: line 199: [SERVICEDIR]=: command not found
    This was compounded by the fact that all of the released
    shorewallrc files still specified SYSTEMDDIR rather than
    SERVICEDIR (Evangelos Foutras)
  * The shorewallrc.archlinux file now reflects a change in SBINDIR
    that occurred in Arch Linux in mid 2013 (Evangelos Foutras).
* Wed Nov  5 2014 toganm@opensuse.org
- Update to versioin 4.6.4.3 For more details see changelog.txt and
  releasenotes.txt
  * The fix for LOG_BACKEND in 4.6.4.2 worked on some older
    distributions but not on newer ones. This release fixes the
    problem in the remaining cases.
* Mon Sep 22 2014 toganm@opensuse.org
- Update to version 4.6.3.4 For more details see changelog.txt and
  releasenotes.txt
  * The 'Universal' configurations previously failed to start with
    the diagnostic
    ERROR: No network interface available: Firewall state not
    changed
  * A defect introduced in 4.6.3 prevented Shorewall-init from
    starting when required interfaces were present.
  * Some defect repair from 4.6.2.5 was inadvertently omitted from
    4.6.3. In particular, the fix for Shorewall-init on systems
    running  systemd was omitted. Those fixes have now been merged
    into this release.
* Sat Sep 13 2014 toganm@opensuse.org
- Update to version 4.6.3.3 For more details see changelog.txt and
  releasenotes.txt
  * Including a PREROUTING SECTION in the accounting file
    unconditionally resulted in a fatal error:
    ERROR: The PREROUTING SECTION is not allowed when
    ACCOUNTING_TABLE=filter
  * Previously, the compiler could generate many superfluous rules
    to enforce the 'tcpflags', 'nosmurfs' and 'maclist' interface
    options.
* Thu Sep  4 2014 toganm@opensuse.org
- Update to version 4.6.3.2 For more details see changelog.txt and
  releasenotes.txt
  * The shorewall[6]-actions manpages previously contained incorrect
    examples of the usage of table names with builtin actions.
    Incorrect:
    FOOBAR,filter,mangle
    Correct:
    FOOBAR   builtin,filters,mangle
  * Previously, if /etc/iproute2/rt_tables was not writeable, then
    KEEP_RT_TABLES=No behaved like KEEP_RT_TABLES=Yes. Now, a
    warning  message is issued if that file is not writeable and
    KEEP_RT_TABLES is set to No.
    WARNING: /etc/iproute2/rt_tables is missing or is not
    writeable
  * In earlier 4.6.3 versions, the help text from shorewall-lite
    and shorewall6-lite included two versions of the 'run' command.
    run <command> [ <parameter> ... ]
    ..
    run <function> [ <parameter> ... ]
    The second one has now been deleted.
  * New Features:
    Eric Teeter has contributed a Citrix Goto Meeting macro.
* Sun Aug 31 2014 toganm@opensuse.org
- Update to version 4.6.3.1 For more details see changelog.txt and
  releasenotes.tx
  * The DNSAmp action released in 4.6.3 matched more packets than it
    should have. That has now been corrected.
  * The handling of REJECT in IP[6]TABLES rules has been clarified
    inthe shorewall-rules(5) and shorewall6-rules(5) manpages.
  * The following misleading error message has now been corrected:
    ERROR: The xxx TARGET is now allowed in the filter table
    The message now reads:
    ERROR: The xxx TARGET is not allowed in the filter table
- Spec fixes
  * Fixed shorewall-init requires so it needs shoreline-firewall
    which is an alias for shorewall shorewall6 shorewall-lite and
    shorewall6-lite packages
  * shorewall-init package was missing a rc link
* Thu Aug 14 2014 toganm@opensuse.org
- Update to version 4.6.2.5 For more details see changelog.txt and
  releasenotes.txt
  * Previously, when an interface specified the 'physical=' option and
    the physical interface name was specified in the INTERFACES
    column of the providers file, compilation would fail with diagnostics
    similar to the following:
    Use of uninitialized value $physicalal in pattern match
    (m//) at /usr/lib/perl5/vendor_perl/5.18.1/
    Shorewall/Providers.pm line 463, <$currentfile> line
    ERROR:ERROR A provider interface must have at least one
    associated zone /zoneopt/etc/shorewall/providers (line 2)
  * Shorewall-init now works correctly on systems with systemd.
    By Louis Lagendijk.
- Remove backported patches
  * PHYSICALNAME.patch
  * 0001-Modify-the-preceding-fix-to-work-with-wildcard-inter.patch
* Wed Aug 13 2014 toganm@opensuse.org
- Backport
  0001-Modify-the-preceding-fix-to-work-with-wildcard-inter.patch
  as the previous patch broke some configurations
* Mon Aug 11 2014 toganm@opensuse.org
- Backported PHYSICALNAME.patch
* Fri Aug  8 2014 toganm@opensuse.org
- Update to version 4.6.2.4 For more details see changelog.txt and
  releasenotes.txt
  + Previously, inline matches were not allowed in action files, even
    though the documentation stated that they were allowed.
* Tue Jul 29 2014 toganm@opensuse.org
- Update to version 4.6.2.3 For more details see changelog.txt and
  releasenotes.txt
  * Previously, the compiler would fail with a Perl diagnostic if:
    + Optimize Level 8 was enabled.
    + Perl 5.20 was being used. This is the current Perl version on
    Arch Linux.
    The diagnostic was:
    Can't use string ("nat") as a HASH ref while "strict refs" in
    use at /usr/share/shorewall/Shorewall/Chains.pm line 3486.
* Fri Jul 25 2014 toganm@opensuse.org
- Update to version 4.6.2.2 For more details see changelog.txt and
  releasenotes.txt
  * The compiler now correctly detects the IPv6 "Header Match"
    capability when LOAD_MODULES_ONLY=No.
  * The compiler now correctly detects the IPv6 "Ipset Match"
    capability on systems running a 3.14 or later kernel.
  * The compiler now correctly detects "Arptables JF" capability
    when LOAD_MODULES_ONLY=No.
  * The tcfilter manpages previously failed to mention that
    BASIC_FILTERS=Yes is required to use ipsets in the tcfilters
    files.
* Sun Jul 20 2014 toganm@opensuse.org
- Update to version 4.6.2.1 For more details see changelog.txt and
  releasenotes.txt
  * Two issues with tcrules processing have been corrected:
    + SAVE and RESTORE generated fatal compilation errors.
    + '|' and '&' were ignored. That issue is also present in the
    processing of the mangle file
  * Version 4.6.2 changes
    + The DSCP match in the mangle and tcrules files didn't work
    with service class names such as EF, BE, CS1, ...
    + The SAVE and RESTORE actions were disallowed in the OUTPUT
    chain in tcrules and mangle; this was a regression from 4.5.21.
    + Additional ports required by Asus, Supermicro and Dell have
    beenadded to the IPMI macro (Tuomo Soini).
    +  Some issues regarding install under Cygwin64 have been
    addressed.
  - configure.pl did not understand CYGWIN returned from `uname`
  - Shorewall-core install.sh did not understand CYGWIN returned
    from  `uname`.
  - The Shorewall and Shorewall6 installers tried to run the
    command 'mkdir -p //etc/shorewall[6]' which is broken in the
    current Cygwin64.
* Sat Jul  5 2014 toganm@opensuse.org
- Update to version 4.6.1.4 For more details see changelog.txt and
  releasenotes.txt
  * The DSCP match in the mangle and tcrles files didn't work with
    service class names such as EF, BE, CS1, ... (Thibaut Chèze)
  * The SAVE and RESTORE actions were disallowed in the OUTPUT
  chain in tcrules and mangle; this was a regression from 4.5.21.
* Wed Jul  2 2014 toganm@opensuse.org
- Update to version 4.6.1.3 For more details see changelog.txt and
  releasenotes.txt
  * Use of the 'IfEvent' action resulted in a compilation failure:
    ERROR: -j is only allowed when the ACTION is INLINE with no
    parameter /usr/share/shorewall/action.IfEvent (line 139)
    from /etc/shorewall/action.SSHKnock (line 8)
    from /etc/shorewall/rules (line 31)
* Thu Jun 19 2014 toganm@opensuse.org
- Update to version 4.6.1.1 For more details see changelog.txt and
  releasenotes.txt
  * An improved error message is generatred when a server address
    list is specified in the DEST colume of a DNAT or REDIRECT
    rule. At one time, iptables supported such lists, but now only
    a single address or an address range is supported.
    The previous error message was:
    ERROR: Unkknown Host (192.168.1.4,192.168.1.22)
    The new error message is:
    ERROR: An address list (192.168.1.4,192.1688.1.22) is not
    allowed in the DEST column of a xxx RULE
    whenere xxx is DNAT or REDIRECT as appropriate.
  * Two problems have been corrected in the Shorewall-init Debian
    init script.
  + A cosmetic problem which releasenotessulted in 'echo_notdone'
    being displayed on failure rather than 'nott done'.
  + More seriously, the test for the existance of compiled
    firewall scripts was incorrect, with the result that the
    firewallingall scripts were not executed.
    These defects, introduced in Shorewall 4.5.17, have now been
    corrected.
- Restating that CHECKSUM.patch is removed since braindead
  factory-auto scripts do not understand previous comment
* Tue Jun 10 2014 toganm@opensuse.org
- Update to version 4.6.1 For more details see changelog.txt and
  releasenotes.txt
  * The release notes in the packages mention a fix for
    'rpfilter'. That defect was actually corrected in 4.5.6.9 with
    a slightly different description in the release notes.
  * Tuomo Soini has provided new macros for AMOP, MongoDB, Redis,
  Sieve and IPMI (RMCP).
* Mon Jun  2 2014 toganm@opensuse.org
- Update to version 4.6.0.3 For more details see changelog.txt and
  releasenotes.txt
  * 1:1 NAT is now enabled in IPv6.
  * subtle interaction between NAT and sub-zones is explained in
    shorewall-nat.
  * The 'show filters' command now works with Simple TC.
* Tue May 27 2014 toganm@opensuse.org
- Update to version 4.6.0.2 For more details see changelog.txt and
  releasenotes.txt
  * The 'upgrade -A' command now converts the tcrules file to a
    mangle file. Previously, that didn't happen.
  * The install components now support RHEL7.
  * Whitespace issues in the skeleton configuration files have been
    corrected (Tuomo Soini).
  * FAQ 2e has been added which describes additional steps required
    to achieve hairpin NAT on a bridge where the modified packets are
    to go out the same bridge port as they entered.
  * shorewall-masq(5) has been corrected to include the word SOURCE
    on the description of that column. Previously, the description
    read '(formerly called SUBNET)'.
  * The output of 'shorewall show filters' once again shows ingress
    (policing) filters. This works around undocumented changes to
    the behavior of the 'tc' utility.
- removed backported CHECKSUM.patch
* Fri May 16 2014 toganm@opensuse.org
- Update to version 4.6.0. For more details see changelog.txt and
  releasenotes.txt. Since this is a major release for those who are
  migrating from previous version, it is important to read the
  above mentioned notes.
  * This release includes all defect repair from releases up through
    4.5.21.9.
- Backported CHECKSUM.patch
* Tue Apr  1 2014 toganm@opensuse.org
- Update to version 4.5.21.9 For more details see changelog.txt and
  releasenotes.txt
  * The output of 'shorewall show capabilities' always showed the
    'Recent match --reap option' as 'Not Available'. 'shorewall
    show -fcapabilities' correctly reported the capability.
  * When a rules file section other than NEW began with a ?COMMENT
    directive, the comment would erroneously appear in the rule
    which jumps to the section chain as well as in the rules directly
    related to the following entries.
  * Rule comments were omitted from the compiler's 'trace' output
    in some cases.
  * When FASTACCEPT=Yes, ESTABLISHED,RELATED accept rules were
    incorrectly omitted from an interfaces's _in and _fwd chains
    when 'rpfilter' was specified in the interfaces's entry in
    /etc/shorewall[6]/interfaces.
* Thu Mar 20 2014 toganm@opensuse.org
- Update to version 4.5.21.8 For more details see changelog.txt and
  releasenotes.txt
  * If an rtrules entry duplicated a Shorewall-generated route rule but
    had a lower priority than the generated one has (20000), then a
    disable/enable sequence on the provider would result in
    duplicate rules with priority 20000.
  * When 'shorewall[6] debug [re]start' was run, any error messages
    generated because of ip[6]tables command errors would not
    include '-t table'.
- Remove 0001-fix-release-version.patch
* Sat Mar  8 2014 toganm@opensuse.org
- Update to version 4.5.21.7 For more details see changelog.txt and
  releasenotes.txt
  * The help text for the 'dump' command has been updated to
    include all valid options.
  * The behavior of ADMINISABSENTMINDED=No is corrected.
    Previously, 'shorewall stop' would not block existing connections
    regardless of the setting of this option. Beginning with this
    release, the behavior of ADMINISABSENTMINDED=No depends on whether
    the  routestopped or the stoppedrules file defines the allow
    connections while the firewall is stopped.
    If there are entries in /etc/shorewall[6]/routestopped or if
    there are no entries in /etc/shorewall[6]/stoppedrules, then the
    behavior of ADMINISABSENTMINDED=No is as documented (existing
    connections are blocked unles they are allowed by
    /etc/shorewall[6]/routestopped).  If there are no entries in
    /etc/shorewall[6]/stoppedrules, then the behavior is as if
    ADMINISABSENTMINDED=Yes and a warning message is generated.
- Add 0001-fix-release-version.patch to correct version info of the
  releasenotes.txt
* Sun Feb  2 2014 toganm@opensuse.org
- Update to version 4.5.21.6 For more details see changelog.txt and
  releasenotes.txt
  * When a non-terminating target specified logging, the compiler
    would erroneously generate a 'goto' (-g) iptables command rather
    than a 'jump' (-j) command. This caused the wrong set of rules
    to be traversed, usually the catchall 'REJECT' or 'DROP' rule
    at theend of the INPUT or FORWARD chain.
    The compiler now generates a 'jump' rule in these cases.
  * When an interface containing a period (such as a VLAN
    interfaceterface) was used in an 'add' or 'delete' command,
    the wrong ipset name was generated, resulting in failure of
    the command.
* Tue Jan 21 2014 toganm@opensuse.org
- Update to version 4.5.21.5 For more details see changelog.txt and
  releasenotes.txt
  * A number of minor updates have been made to the documentation
    and manpages.
  * The 'postcompile' extension script is now documented at
    http://www.shorewall.org/shorewall_extension_scripts.htm
  * The 'add' command previously failed if 'IPSET=' appeared in the
    shorewall.conf file. This has been corrected.
* Sat Nov 23 2013 toganm@opensuse.org
- Update to version 4.5.21.4 For more details see changelog.txt and
  releasenotes.txt
  * The Broadcast actions have been corrected:
  - --dst-type BROADCAST has been removed from the IPv6 version
  - A superfluous DROP rule in the IPv4 version has been
    suppressed.
  * Previously, if an HFSC class was specified with dmax but not
    umax, then the firewall would fail to start with the messages:
    Nov 14 13:42:42 Setting up Traffic Control...
    HFSC: Illegal "umax"
    HFSC: Illegal "sc"
    ERROR: Command "tc class add dev eth1 parent 1:1 classid
    1:110  hfsc sc umax b dmax 150ms rate 1575kbit ul rate 3150kbit"
    Failed
    That problem has been corrected.
  * The tcrules file now supports DROP entries to allow early
    dropping of DOS packets.
* Mon Oct 21 2013 toganm@opensuse.org
- Update to version 4.5.21.2 For more details see changelog.txt and
  releasenotes.txt
  * Previously, the AutoBL action would fail if the kernel and
    iptables did not support the Recent Match '--reap' option. A new
    REAP_OPTION  capability has been added to work around this issue.
  * The Shorewall-core installer no longer reports an error from
    'cp' stating that it could not stat the shorewallrc file.
  * When a non-root user attempts to execute 'version -a', the CLI
    no longer attempts to get the version of the compiled
    firewall. Previously, the command issued the following
    diagnostic when run by non-root:
    /sbin/shorewall: /var/lib/shorewallhorewall/firewall:
    Permission denied
  * Shorewall no longer uses 'fgrep' thus allowing for use on
    systems without that utility. All uses of 'fgrep' have been
    replaced by 'grep -F'.
  * Placing |<mark> in the ACTION column of the tcrules file no
    longer raises a fatal compilation error.
* Wed Oct  9 2013 toganm@opensuse.org
- Update to version 4.5.21.1 For more details see changelog.txt and
  releasenotes.txt
  * Problems with the Shorewall Init installer (install.sh) were
    corrected. These problems affected initial Gentoo and Debian
    installs.
  * A problem that prevented multiple ICMP/ICMP6 types to be
    specified in a rule has been corrected.
  * Previously, an attempt to specify RAS or Q.931 in the HELPER
    column  was rejected with an error.
  * The 'nohostroute' provider option was not honored in the
    default table when USE_DEFAULT_RT=Yes.
* Thu Oct  3 2013 toganm@opensuse.org
- Update to version 4.5.21 For more details see changelog.txt and
  releasenotes.txt
  * ip[6]tables 1.4.20 introduced an incompatible change that
    causes the program to fail if there is another instance of either
    iptables or ip6tables already running. This behavior can be avoided
    if the new -w option is specified.
    To work around this problem, the compiler now uses the -w
    option (when available) during capabilities determination so that
    shorewall and shorewall6 compilations can proceed in parallel.
  * Previously, the Shorewall-init installer unconditionally
    installed the sysconfig file even when a different SYSCONFFILE was
    specified. (Thomas D).
  * /sbin/shorewall-init now includes the correct SYSCONFDIR name
    in its error message that reports the absense of
    ${SYSCONFDIR}/shorewall-init. (Thomas D).
  * /sbin/shorewall-init and the Shorewall-init SysV init scripts
    now honor the setting of $OPTIONS.
  * The -lite installers now look in ${SHAREDIR} for the
    coreversion file rather than in /usr/share/.
  * If a Shorewall-lite installation used an
    /etc/shorewall-lite/vardir file to set a non-standard state
    directory, the administrative system would send the firewall
    and firewall.conf files to the wrong directory on the firewall
    system.
  * Previously, the compiler verified 'monthdays' specifications in
    the rules TIME column, but failed to include --monthdays in the
    generated rule. That omission has been corrected.
  * The Multicast DNS macros (mDNS and mDNSbi) now allow the entire
    non-priv port range (1024-65535) for the the dynamic unicast
    port. Previously, only the Linux 2.6+ dynamic port range
    (32768-65535) were allowed.
- Spec file changes
  * Add 0001-fillup-install.patch
  * Remove shorewall-init-4.5.15-install.patch
* Wed Aug 28 2013 toganm@opensuse.org
- Update to version 4.5.20 For more details see changelog.txt and
  releasenotes.txt
  * A typographical error in the usage text produced by the -h
    command in the compiled firewall script has been corrected.
  * The handling of INITSOURCE is now uniform between the standard
    and the -lite installers.
  * Previously, when SYSCONFFILE was specified in shorewallrc, the
    installers would always install default.debian rather than the
    named file. That has been corrected.
- Spec file changes
  * removed the following pathces:
    0001-Os-release.patch
    0001-Fix-Exec-directory.patch
* Thu Aug  8 2013 toganm@opensuse.org
- Spec file changes
  * Add 0001-Os-release.patch Fixes bnc#833999
  * dropped 0001-Use-etc-os-release-as-of-release-13.1.patch
* Thu Aug  8 2013 toganm@opensuse.org
- Spec file changes
  * Added 0001-Use-etc-os-release-as-of-release-13.1.patch
    Fixes bnc#833999 for /etc/os-release
* Wed Jul 24 2013 toganm@opensuse.org
- Update to version 4.5.19 For more details see changelog.txt and
  releasenotes.txt
  * Previously, the '-q' option did not suppress all output from
    certain commands such as 'check'.
* Sun Jun 30 2013 toganm@opensuse.org
- Spec file changes
  * Added 0001-Fix-Exec-directory.patch which fixes ExecStart
    ExecStop path of systemd shorewall-init.service (bnc#827524)
  * removed  systemd.patch
* Sun Jun 30 2013 toganm@opensuse.org
- Update to version 4.5.18 For more details see changelog.txt and
  releasenotes.txt
  * This release includes all defect repair from Shorewall
    4.5.17.1.
  * The following warning message could be emitted inappropriately
    when running shorewall 4.5.17.
    The rule(s) generated by this entry are unreachable and have
    been discarded
    These warnings, which were disabled in Shorewall 4.5.17.1, are
    now only emitted where appropriate. The message has also been
    reworded to:
    One or more unreachable rules in chain <name> have been
    discarded
    The message is issued a maximum of once per Netfilter chain.
  * A problem that could cause the 'trace' compiler option to
    produce false error messages or to produce an altered generated
    firewall script has been corrected.
  * If the 'Owner Name Match' capability was not available, the
    following error message would previously appear during
    compilation:
    iptables: No chain/target/match by that name.
- spec file changes
  * rebased systemd.patch
* Wed Jun  5 2013 toganm@opensuse.org
- Update to version 4.5.17.1 For more details see changelog.txt and
  releasenotes.txt.
  * The following warning message may be emitted inappropriately
    when running shorewall 4.5.17. The message is no longer issued.
    The rule(s) generated by  this entry are unreachable and have
    been discarded
  * Rules intended to increment nfacct objects would previously be
    optimized away when they immediately preceded an unconditional
    jump to the same target. Such rules are now retained.
  * A bug in the optimizer in 4.5.17 can cause 'set' and 'geoip'
    matches to be dropped. That has been corrected.
- spec file changes
  * rebased systemd.patch
* Thu Apr  4 2013 toganm@opensuse.org
- Update to version 4.5.15 For more details see changelog.txt and
  releasenotes.txt
  * Previously, the Shorewall and Shorewall6 install.sh scripts did
    two things wrong with respect to the /etc/shorewall[6]/routes
    file:
    + The existing file was unconditionally removed.
    + A skeleton file was not installed when SPARSE was not set in
    the shorewallrc file.
    Additionally, the installer would remove /etc/shorewall[6]/tcstart
  * The Shorewall-init install.sh script previously refused to
    replace /sbin/ifup-local and /sbin/ifdown-local when those files has
    been installed by an earlier version of Shorewall-init.
  * Previously, Shorewall-init's integration with NetworkManager
    was incomplete on SuSE with the result that NetworkManager
    interface change events were not processed. That has been corrected.
  * Beginning with Shorewall 4.5.8, Shorewall6 has interpreted /32
    networks as hosts (/128). /32 IPv6 networks are once again
    handled correctly.
  * Using names such as such as EF, BE, CS1, ... for DSCP didn't
    work previously. Thibaut Chèze has provided a fix.
  * An incorrect range test prevented DSCP classes CS6 and CS7 from
    being accepted. The test has been corrected and those classes
    are now allowed.
- spec file changes
  * rebased systemd.patch
  * added shorewall-init-4.5.15-install.patch and removed
    shorewall-init-4.5.2-install.patch
* Mon Mar 11 2013 toganm@opensuse.org
- Update to version 4.5.14 For more details see changelog.txt and
  releasenotes.txt
  * Previously, a list of IPv6 host addresses where each address
    was enclosed in square brackets generated a fatal compile-time
    error.
    Such lists are now handled correctly.
  * The Shorewall 'load', 'reload' and 'export' commands have now
    been modified to use a shorewallrc file in a remote system's export
    directory. If the directory layout of the remote system differs
    from that of the administrative system, then the remote
    system's export directory should contains a copy of that system's
    shorewallrc file.
  * A syntax error in the Shorewall uninstall.sh file has been
    eliminated.
  * The contents of the various configpath files have been
    corrected.
  * The Shorewall uninstall.sh script previously failed to remove
    the  macro files from ${SHAREDIR}/shorewall. Those files are now
    removed.
  * The 'version -a' command now prints the correct shorewall-core
    version when it is run from shorewall6, shorewall-lite and
    shorewall6-lite.
  * It is now possible to specify a port or port range along with
    an address variable in the ADDRESSES column of/etc/shorewall/masq.
    Example:
    [#]INTERFACE      SOURCE          ADDRESS         PROTO   DEST
    [#]                                                       PORT(S)
    eth0            172.20.4.0/24   &eth0:44        tcp     45
    Previously, this usage generated a fatal compilation error.
  * Port numbers and service names may now be specified with the
    UDPLITE protocol.
  * The SUBSYSLOCK setting in the default shorewall6.conf file has
    been changed from /var/lock/subsys/shorewall to
    /var/lock/subsys/shorewall6.
- rebased systemd.patch
* Wed Feb 13 2013 toganm@opensuse.org
- Update to version 4.5.13 For more details see changelog.txt and
  releasenotes.txt
  * If a chain consisted of a single RETURN rule, optimize level 4
    would handle it incorrectly by moving the RETURN rule to the
    chain(s) that jumped to the single-rule chain. The optimizer
    now simply eliminates the chain and rule.
    As part of this change, the optimizer now deletes trailing
    RETURN  rules from chains.
  * If a default inline action was specified with parameters, the
    compiler would fail with an internal error.
  * The compiler was mis-handling simple arithmetic expressions
    consisting of a single number, evaluating the number as ''
    rather than as its numberic value.
- Rebased systemd.patch
* Sun Jan 20 2013 toganm@opensuse.org
- Update to version 4.5.12 For more details see changelog.txt and
  releasenotes.txt
  * This release contains the defect repairs from Shorewall
    4.5.11.1 and 4.5.11.2.
  * Two defects associated with 'update -D' have been corrected.
    + shorewall.conf.bak is no longer deleted.
    + files that are not changed no longer have their mtime updated.
  * Inline actions in the RELATED and ESTABLISHED sections now work
    correctly.
  * The 'dropInvalid' built-in function now works correctly.
  * The compiler now generates an error when a protocol list is
    used in a context where only a single protocol name/number is
    accepted.
  * The generated script now correctly deletes Traffic Control
    configurations when CLEAR_TC=Yes. Previously, the
    configurations on interfaces with a '@xxxxxx' suffix in their
    names were not cleared.
  * Under very rare circumstances, optimize level 4 could leave a
    rule that jumped to a non-existant chain, causing
    iptables-restore to fail.
  * If an error was raised while compiling a default action, a Perl
    diagnostic could appear and the Shorewall error message would
    not be printed.
  * It is once again possible to use DNS names in rules without an
    interface name.
* Tue Jan 15 2013 toganm@opensuse.org
- Added systemd.patch to fix the exec path (bnc# 798525)
* Sat Jan 12 2013 toganm@opensuse.org
- Update to 4.5.11.2 For more details see changelog.txt and
  releasenotes.txt
  * Corrected fix 2 from 4.5.11.1.
  * 4.5.11.1
  Beginning with Shorewall 4.5.10, if the name of an optional
  interface contained one or more characters that are not valid
  in a  shell function name, then the generated script would fail with
  a "syntax error: bad function name" shell diagnostic.
  That problem has been corrected so that a valid function name
  is generated.
  * The kernel modules supplied by xtables-addons are now listed in
    the modules.xtables files. They were previously omitted.
* Mon Dec 17 2012 toganm@opensuse.org
- Update to 4.5.10.1 For more details see changelog.txt and
  releasenotes.txt
  * Correct typo in conntrack module
* Sun Dec  9 2012 toganm@opensuse.org
- Update to 4.5.10 For more details see changelog.txt and
  releasenotes.txt
  * This release includes all defect repair included in
    4.5.9.1-4.5.9.3.
  * Under rare circumstances, optimize level 16 could produce
    invalid iptables-restore input which would cause start/restart
    to fail.
  * Before this release, the 'started' script was run prior to
    copying the temporary script file (e.g., /var/lib/shorewall/.start)
    to /var/dir/shorewall/firewall. If the script failed, the copy
    would not take place even though the firewall had started
    successfully. The script is now copied before running the
    'started' script.
    If you compare the script generated by this release with one
    generated by a prior release, We suggest that you ignore
    whitespace changes (e.g., use the '-w' option in diff); that way,
    you can see the actual change more clearly.
  * AUTOCOMMENT=No now works correctly; previously, it behaved the
    same as AUTOCOMMENT=Yes.
  * A harmless extraneous comma has been deleted from the rule
    generated by action.RST.
* Wed Nov 21 2012 toganm@opensuse.org
- Update to 4.5.9.2 For more details see changelog.txt and
  releasenotes.txt
  * Previously, the rules in the 'routemark' chain did not specify
  a mask in the MARK target. While a mask isn't strictly necessary
  in those rules, one has been added to ally fears of those who read
  the  generated ruleset.
    Note: The 'routemark' chain is used to apply provider marks to
    packets received from 'track' provider interfaces. It is
    traversed  early in the mangle PREROUTING chain when no other
    marks have yet been applied to the packet.
  * If exclusion was used with TPROXY in the tcrules file, an
  invalid  iptables ruleset was generated causing start and
  restart commands  to fail when running iptables-restore.
  * Previously, if a provider and its interface had the same name,
  then the 'enable' command would not work on that interface.
* Sat Nov 10 2012 toganm@opensuse.org
- Update to 4.5.9.1 For more details see changelog.txt and
  releasenotes.txt
  * Previously, using a wildcard interface name in a rule would
    result in this error:
    ERROR: Invalid ipset name (ppp+) : ...
    Such entries are now handled correctly.
  * The shorewall-masq(5) manpage incorrectly stated that the
    SOURCE column may use exclusion with an interface name (e.g.,
    eth1:!1.2.3.4). That hasn't been the case for some time. To
    accomplish the same thing, do this:
    eth0    1.2.3.4   NONAT
    eth0    eth1
    Note: Using an interface name in the SOURCE column is deprecated.
  * Previously, if a MARK was specified for a tc class that
    explicitly specified a class number, the following spurious
    warning message was issued:
    WARNING: Class NUMBER ignored --
    INTERFACE <name> does not have the 'classify' option
    That warning message is no longer issued.
  * With Shorewall 4.5.9, there were issues when the ipset utility
    was not installed, some of which prevented Shorewall from
    starting.
- Adjust for the usr move
  * change /sbin/service to /usr/service in requires and setting links
* Tue Oct 30 2012 toganm@opensuse.org
- Update to 4.5.9 For more details see changelog.txt and
  releasenotes.txt
  * This release contains all defect repair from Shorewall 4.5.8.2.
  * A typo has been corrected in the shorewallrc.default file.
  * Beginning with Shorewall 4.5.7.2, Shorewall unconditionally
    restores the provider mark as the first rule in the mangle
    table OUTPUT and PREROUTING chains. Previously, the provider
    mark was restored only if it was non-zero.
    It has become clear that some users need it one way while
    others need it the other way. To resolve this issue, a
    RESTORE_ROUTEMARKS option has been added to shorewall.conf and
    shorewall6.conf. When this option is set to Yes (the default),
    the 4.5.7.2 approach is used (always restore the mark, even if
    it is zero); when it is set to No, the pre-4.5.7.2 behavior is
    retained (only restore the mark if it is non-zero).
  * Two error messages produced by the RST action have been
    corrected. They previously referred to errors in the NotSyn
    action rather than RST.
* Wed Oct 10 2012 toganm@opensuse.org
- Update to 4.5.8.2 For more details see changelog.txt and
  releasenotes.txt
  * The 'shorewall show' command previously produced no output.
    That command now works with ipset versions 4 and later.
  * The change in 4.5.8.1 that enabled industry-standard IPv4
    address representation broke the ability to place IP ranges or
    IPv6 ipsets in the hosts file. Those abilities have been
    restored.
  * The treatment of the SYSTEMD and INITFILE shorewallrc variables
    has been inconsistent. The -lite installers ignore INITFILE
    when SYSTEMD is specified, while the other installers do not.
    Now, the -lite installers install the .service file if SYSTEMD
    is specified and they install the sysv-init script if INITFILE
    is specified. That is consistent with the behavior of the other
    installers.
* Sun Oct  7 2012 toganm@opensuse.org
- Update to 4.5.8.1 For more details see changelog.txt and
  releasenotes.txt
  * When ipset version 5 or later was installed, the 'shorewall show
    dynamic <zone>' command produced no outout and the 'add' command
    failed with this error message:
    Zone <zone>, interface <interface> does not have a dynamic
    host list"
  * When generating ipset names for dynamic zones, the compiler was
    dropping dashes ('-') from the interface name and adding a unique
    suffix. For example the ipset for zone 'foo' and interface 'bar-if'
    might be 'foo_barif_1'. Dashes are now retained so that the
    generated set name in this example will be 'foo_bar-if'. This change
    also allows the 'add' and 'delete' commands to work correctly when
    the interface name contains one or more dashes.
    Although dash is documented as being an accepted character in ipset
    names, names containing a dash would generate an error in some
    contexts. That has also been corrected.
  * In most contexts, Shorewall6 has required IPv6 addresses to be
    enclosed in either angled brackets ( <....> , deprecated) or in
    square brackets ([....]). This includes network addresses, where
    both the IPv6 address and the VLSM are required to be within the
    brackets (e.g., [2001;470:b:787::/64]). This differs from the
    industry-standard network form in which the IPv6 address is enclosed
    in square brackets and the VLSM is outside of the brackets (e.g.,
    [2001:470:b:787::]/64). Beginning with this release, the
    industry-standard representation is also accepted by Shorewall6.
    Note: Those of you who read the patches will probably have noticed
    that much of this change was actually in 4.5.8; because the change
    was commited late in the 4.5.8 release cycle, we chose not to
    document the change until it had undergone additional testing.
-  Added 0001-remote_fs.patch for shorewall-init sysv-init scripts
  rebased patches to -p1 level
* Fri Oct  5 2012 toganm@opensuse.org
- Update to 4.5.8 For more details see changelog.txt and
  releasenotes.txt
  * This release includes the defect repair from Shorewall 4.5.7.1.
  * The restriction that TTL and HL rules could only be placed in
    the FORWARD chain prevented these rules from being used to hide
    a router from traceroute[6]. It is now allowed to place these
    rules in the PREROUTING chain by following the specification
    with ':P' (e.g., 'TTL(+1):P').
  * Previously, the macro.SNMP macro opened both UDP ports 161 and
    162 from SOURCE to DEST. This is against the usual practice of
    opening these ports in the opposite direction. Beginning with
    this release, port 162 is opened in to SOURCE to DEST as
    before, while port 161 is opened from DEST to SOURCE.
  * Previously, when compiling for export, both
    /etc/shorewall/shorewall[6].conf and the shorewall[6].conf in
    the configuration directory were processed. Now, only the copy
    in the configuration directory is processed.
  * The 'iptables_raw' module has been added to the
    modules.essential file.
  * Several corrections have been made to the Fedora/Redhat init
    script for Shorewall-init.
  * The <directory> parameter to the 'try' command is now
    documented in the shorewall(8) and shorewall6(8) manpages.
  * Some redundant interface-option rules have been removed in
    configurations with multiple zones configured on a single
    interface.
  * Previously, when compiling for export, the compilation would
    fail if the setting of SHAREDIR in the firewall's shorewallrc
    was different from the setting on the admin system. Such
    compilations now succeed.
- For openSUSE 12.3 provide only systemd and drop sysv-init scripts
* Mon Sep 24 2012 toganm@opensuse.org
- Since shorewall executables are in /usr/sbin systemd service
  files now reflect the correct location
* Mon Sep  3 2012 toganm@opensuse.org
- Update to 4.5.7.1 For more details see changelog.txt and
  releasenotes.txt
  * When using IPSEC in a multi-ISP configuration, it is possible
    for the kernel to mis-route ESP packets. To date, this problem
    has only been observed on a system running a 3.5 kernel where
    traffic is being tunneled through GRE which is in turn being
    tunneled via IPSEC.
    This Shorewall release includes a low-cost workaround.
  * The Netfilter team have announced their intention to remove the
    NOTRACK target in favor of 'CT --notrack'. Shorewall will now
    map  NOTRACK to 'CT --notrack' if the CT Target is available.
  * Previously, the current COMMENT was not being cleared after the
    blrules file was processed, causing that COMMENT to be used on
    entries in the rules file. That defect has been corrected.
- Add a note to the spec for reviewer explaining the configure
  command usage
- Removed following opensuse specific patches as they are merged to
  upstream now
  + shorewall-lite-4.5.2-init.patch
  + shorewall6-4.5.2-init.patch
  + shorewall6-lite-4.5.2-init.patch
  + shorewall-init-4.4.21_init_sh.patch
- Added 001-required-stop-fix patch for shorewall-lite/init.suse.sh
* Tue Aug 21 2012 toganm@opensuse.org
- Update to 4.5.7 For more details see changelog.txt and
  releasenotes.txt
  * This release includes the defect repair from Shorewall 4.5.6.2.
  * The command 'shorewall enable pppX' could fail with the ip
    diagnostic Error: either "to" is duplicate, or "weight" is a
    garbage.
    Shorewall now generates the correct ip command.
  * Optimize level 4 could previously combine two rules that each
    specified the 'policy' match, leading to this iptables-restore
    failure:
    policy match: multiple elements but no --strict
    The optimizer now avoids combining such rules.
    While this is a long-standing defect in the optimizer, it was
    exposed by changes in Shorewall 4.5.6.
  * There were several cases where hard-wired directory names
    appeared in the tarball installers. These have been replaced
    with the appropriate shorewallrc variables.
  * A defect in RHEL 6.3 and derivatives causes 'shorewall show
    capabilities' to leave an empty ipset in the configuration. The
    same defect can cause the Shorewall compiler to similarly leave
    an empty ipset behind.
    This Shorewall release has a workaround for this problem.
-  Added Bash >= 4 to BuildRequires
-  Fix builds for Fedora
* Wed Aug  8 2012 toganm@opensuse.org
- Update to 4.5.6.2 For more details see changelog.txt and
  releasenotes.txt
  * The compiler now generates an error when a SOURCE interface is
    specified in a rule where the SOURCE zone is the firewall
    itself.
  * Previously, entries in /etc/shorewall/notrack that specified a
    Vserver zone in the SOURCE column were omitted from the
    generated  ruleset.
  * The set of helpers available in the notrack file and in the
    HELPER column of the tcrules file was incorrect:
  - The Amanda helper requires a UDP port -- Shorewall was
    requiring
    TCP.
  - The H323 module supplies two helpers: 'RAW' and 'Q.931';
    Shorewall only accepted 'h323'.
  - The Netbios NS module supplies the 'netbios-ns' helper;
    Shorewall
    only accepted 'netbios_ns'.
  * The conditional directive '?IF 0' generated an error from the
    compiler. It now causes following lines to be omitted.
* Tue Jul 10 2012 toganm@opensuse.org
- Update to 4.5.6 For more details see changelog.txt and
  releasenotes.txt
  * This release includes the defect repairs from Shorewall 4.5.5.1
    through 4.5.5.4.
  * Previously, the tcrules file was not processed when
    TC_ENABLED=No. That meant that to use features like TPROXY, it
    was  necessary to set TC_ENABLED=Yes and create a dummy
    /etc/shorewall/tcstart file. Now, only MANGLE_ENABLED=Yes is
    required.
* Sun Jul  1 2012 toganm@opensuse.org
- Update to 4.5.5.3 For more details see changelog.txt and
  releasenotes.txt
  * When logical interface names were used, an entry in tcrules
    that included a classid could result in the compiler failing with
    this Perl diagnostic:
    Can't use an undefined value as an ARRAY reference at
    /usr/share/shorewall/Shorewall/Tc.pm line nnn, <$currentfile>
    line 20.
* Fri Jun 15 2012 toganm@opensuse.org
- Update to 4.5.5.1 For more details see changelog.txt and
  releasenotes.txt
  * The change in Shorewall 4.5.4 that cleared the 'default' table
    if there were no 'fallback' providers broke multiple 'fallback'
    providers that don't supply a weight. The symptoms were that
    there were host routes to the default gateways in the 'default'
    routing table but no default routes through those gateways.
    This has now been corrected and multiple 'fallback' routes are
    once again supported.
  * When a logical device name was specified in the REDIRECTED
    INTERFACES column of /etc/shorewall/tcdevices, that name was
    used in the generated script rather than the devices's physical
    name. Unless the two were the same, this caused start/restart
    failure. Shorewall now uses the physical name.
* Sat Jun  9 2012 toganm@opensuse.org
- Update to 4.5.5 For more details see changelog.txt and
  releasnotes.txt
  * This release includes all defect repair from Shorewall 4.5.4.1
    and 4.5.4.2.
  * The Shorewall compiler sometimes must defer generating a rule
    until runtime. This is done by placing shell commands in its
    internal representation of a chain. These commands are then
    executed at run time to create the final rule.
    If all of the following were true, then an incorrect ruleset
    could be generated:
    + Optimization level 4 was set.
    + A chain (chain A) containing shell commands had three or
    fewer rules and commands.
    + The last rule in a second chain was a conditional jump to
    chain A.
    Under these conditions, the rules and commands in Chain A
  * The Shorewall-core configure and configure.pl script were
    treating SYSCONFDIR as a synonym for CONFDIR making it
    impossible to set SYSCONFDIR.
* Thu Jun  7 2012 toganm@opensuse.org
- Update to 4.5.4.2 For more details see changelog.txt and
  releasenotes.txt
  * The problems corrected section of the 4.5.4.1 release notes was
    missing the third problem corrected in the release. It has now
    been added.
  * A number of problems in Shorewall-init have been corrected:
    + If more than one product was listed in the PRODUCTS setting
    in /etc/default/shorewall-init (/etc/sysconfig/shorewall-init)
    then the second product would not be started/stopped.
    + Shorewall-init used 'restart' in response to an optional
    provider interface coming up. If the interface has been
    marked unusable (1 in the interface's .status file), then the
    'restart' would not enable the interface.
    + Shorewal-init produced a lot of clutter on the console
    during boot. You may now specify a LOGFILE in
    /etc/default/shorewall-init (/etc/sysconfig/shorewall-init)
    and all output produced by up and down events will be sent to
    that log. If no log is specified, this output is sent to
    /dev/null.
  * The order in which the compiler processes line-continuation
    (line ending in '\') and conditional-inclusion directives (?IF,
    ?ELSE, and ?ENDIF) has been reversed.
    Previously, the compiler built a concatenated line, then
    checked to see if the line began with ?IF, ?ELSE or ?ENDIF. Now, the
    compiler checks for ?IF, ?ELSE or ?ENDIF first and prevents
    those lines from becoming part of the concatenation.
  * Two issues with the shorecap programs have been corrected:
    + The Shorewall6-lite version failed to run with the message:
    /usr/share/shorewall6-lite/lib.cli: No such file or
    directory
    + The Shorewall-lite version would not run if SHAREDIR was
    set to a value other than /usr/share in shorewallrc.
  * The Shorewall 4.5.2.3 fix for the Shorewall-core installer's
    handling of --host=linux was not brought forward into 4.5.3.
    It has been included again in this version.
  * Single-line embedded PERL and SHELL commands have been
    re-enabled.
* Fri Jun  1 2012 toganm@opensuse.org
- Update to 4.5.4.1 For more details see changelog.txt and
  releasenotes.txt
  * Beginning with Shorewall 4.4.22, the 'pptpserver' tunnel type
    has been configured as a PPTP client running on the firewall
    rather than as a server on the firewall. It is now correctly
    configured as  a server.
  * The shorewall-accounting (5) and shorewall6-accounting (5)
    documentation for the IPSEC column is incorrect. Rather than
    'accountin' and 'accountout', the chain names should be
    'accipsecin' and 'accipsecout'.
  * IPSEC accounting did not work if the accounting file was
    sectioned. Beginning with this release, the IPSEC column can
    be specified in any section. As always, the IPSEC column
    contains a comma-separated  list of items. In the FORWARD
    chain, the first (or only) item in the list must be either
    'in' or 'out' to indicate whether the rule  matches incoming
    packets that have been decrypted ('in') or outgoing packets
    that will be encrypted ('out'). There are no restrictions with
    respect to which chain IPSEC rules can appear in  a sectioned
    file.
* Sat May 26 2012 toganm@opensuse.org
- Update to 4.5.4 For more details see changelog.txt and
  releasenotes.txt
  * When EXPORTMODULES=No in shorewall.conf, the error messages
    have been eliminated
  * If the configuration settings in the PACKET MARK LAYOUT section
    of shorewall.conf (shorewall6.conf) had empty settings, the
    'update' command would previously set them to their default
    settings. It now  leaves them empty.
  * Previously, Shorewall used 'unreachable' routes to null-route
    the RFC1918 subnets. This approach has two drawbacks:
  - It can cause problems for IPSEC in that it can cause packets
    to be rejected rather than encrypted and forwarded.
  - It can return 'host unreachable' ICMPs to other systems that
    attempt to route RFC1918 addresses through the firewall.
    To eliminate these problems, Shorewall now uses 'blackhole'
    routes.
    Such routes don't interfere with IPSEC and silently drop
    packets  rather than return an ICMP.
  * The 'default' routing table is now cleared if there are no
    'fallback' providers.
  * Tproxy implementation has been reworked. For more details
    please consult the releasenotes.txt and changelog.txt
* Tue May 15 2012 toganm@opensuse.org
- Update to 4.5.3.1 For more details see changelog.txt and
  releasenotes.txt
  * Previously, nested conditionals did not work correctly in all
  cases. In particular:
    ?IF $FALSE
    ?IF $FALSE
    foo
    bar
    ?ENDIF
    baz
    bop
    ?ENDIF
    In this case, the lines 'baz' and 'bodyp' were incorrectly
    included when they should have beeen omitted.
  * The 'balance' routing table is now cleared if there are no
    'balance' providers.
  * Previously, the compiler generated an invalid 'ip add route'
    command if an IPv6 provider had '-' in the GATEWAY column.
  * As noted in the Migration Considerations, the generated
    firewall script maintains the interface .status files used by
    LSM and SWPING. Up to now, however, the 'disable' command did
    not update the .status file. That has been corrected. As part
    of the change, the 'isusable' script is no longer consulted by
    the'enable' command.
* Fri May 11 2012 toganm@opensuse.org
- Update to 4.5.3 For more details see changelog.txt and
  releasenotes.txt
  * The LOCKFILE setting in shorewall.conf and shorewall6.conf had
    inadvertently become undocumented. It is now documented again.
  * In an initial installation of Shorewall, Shorewall6, Shorewall
    Lite or Shorewall6 Lite was done under Shorewall 4.5.2, then the
    firewall would not start up at boot even though the installer
    indicated that it would. That defect has been corrected.
  * Previously, when per-IP rate limiting was invoked, the compiler
    would use the deprecated '--ratelimit' option, even if the
    preferred '--ratelimit-upto' option was available. Now, the
    compiler uses the preferred option if it is supported by the
    installed version of iptables.
  * Prior to this release, using a manual chain in the ACTION
    column of a macro body generated an error:
    ERROR: Invalid Action (mychain) in macro, macro.FOO (line ...)
    This now works correctly and generates a jump to the specified
    manual chain.
  * Previously, a line with the single word COMMENT in the tunnels
    file would generate the following error:
    ERROR: Zone must be specified
    Now, such a line correctly resets the current rule comment.
  * In Shorewall 4.5.2, the MARK column in the tcrules file was
    renamed to ACTION but only 'mark' was accepted in the alternate
    specification format. Now both 'mark' and 'action' are
    accepted.
  * The alternative method of provider balancing using the
    statistic match feature of iptables/Netfilter was missing some
    logic, with the result that it was ineffective.
  * If a logical interface name was used by itself in the SOURCE
    column of the rtrules file, the generated routing rule would
    contain the logical name rather than the physical name.
* Tue May  1 2012 toganm@opensuse.org
- Update to 4.5.2.4 For more details see changelog.txt and
  releasenotes.txt
  * The 'shorewall reset' command now correctly resets the IPv4
    packet and byte counters; previously, it was resetting the IPv6
    counters.
  * The Shorewall installer now modifies the Chains.pm file for
    Digest::SHA depencency when $DESTDIR is set, provided that
    $BUILD = $HOST. This allows rpm to automatically generate the correct
    module dependency.
* Sun Apr 15 2012 toganm@opensuse.org
- Update to 4.5.2.2 For more details see changelog.txt and
  releasenotes.txt
  * If a shorewallrc file is passed to the 4.5.2.1 Shorewall-core
    install.sh, subsequent compilations fail. The error message
    indicates that the compiler is looking for lib.core, but the
    pathname has embedded spaces.
  * The 4.5.2.1 Shorewall/Shorewall6 installer installs an
    incorrect file as /etc/shorewall[6]/Makefile.
* Sat Apr 14 2012 toganm@opensuse.org
- Update to 4.5.2.1 For more details see changelog.txt and
  releasenotes.txt
  * In release 4.5.2, if an INCLUDE directive appeared inside a ?IF
    ... ?ENDIF sequence, then the following error would be
    generated after the included file had been read:
    ERROR: Missing ?ENDIF to match the ?IF at line ...
  * An error in the shorewallrc.apple file has been corrected.
  * The shorewallrc.redhat file has been change to conform to
    Fedora packaging guidelines.
  * The output of the 'version -a' command reflected incorrect
    versions when Shorewall-core 4.5.2 was installed. That has been
    corrected.
* Fri Apr 13 2012 toganm@opensuse.org
- Update to 4.5.2 For more details see changelog.txt and
  releasenotes.txt
  * The generated firewall script includes code to automatically
    create ipsets that are referenced but that don't exist. That code
    was broken in releases 4.4.22 and later. This defect has been
    corrected. As part of the fix, the generated script will now
    issue a warning message when it creates an ipset.
  * The 'mss' option is now supported in the /etc/shorewall[6]/hosts
    files. See the manpages for details.
  * It is now possible to conditionally include or omit
    configuration entries based on the settings of shell variables.
    See  http://www.shorewall.net/configuration_file_basics.htm
    for details.
  * The MARK/CLASSIFY column in /etc/shorewall[6]/tcrules has been
    renamed ACTION to reflect the expanded set of actions that can
    be specified in the column.
  * Some users are finding these ipset warnings objectionable:
    + Warning when a referenced ipset does not exist.
    + Warning when using [src] in a destination column or [dst] in
    a source column.
    These warnings may now be suppressed by setting
    IPSET_WARNINGS=No  in shorewall.conf and/or shorewall6.conf.
* Tue Mar 20 2012 toganm@opensuse.org
- Update to 4.5.1.1 For more details see changelog.txt and
  releasenotes.txt
  * When checking or compiling for export (-e option),
    /sbin/shorewall would previously issue a warning message if
    the SHOREWALL_SHELL specified in the remote
    firewall's shorewall.conf did not exist.
  * The changes to TOS handling in 4.5.1 are incompatible with
    older releases such as RHEL5 and derivatives. That has been
    corrected.
  * The rules compiler now verifies that the protocol is TCP, UDP,
    SCTP or DCCP when checking a port range (low:high or low-high).
  * Previously, start or restart using the init script would fail
    with an error message referencing 'SHOREWALL_INIT_SCRIPT'.
    This defect was not visible to users that set AUTOMAKE=Yes or
    that run Shorewall-init.
* Fri Mar 16 2012 toganm@opensuse.org
- Update to 4.5.1 For more details see changelog.txt and
  releasenotes.txt
  * This release includes all defect repair from versions
    4.5.0.1-4.5.0.3.
  * A typo has been corrected in the blrules man pages.
  * Previously, if the interface appearing in the HOSTS column of
    /etc/shorewall6/hosts was not defined in
    /etc/shorewall6/interfaces, then the compiler would terminate
    with a Perl diagnostic:
    Can't use an undefined value as a HASH reference at
    /usr/share/shorewall/Shorewall/Zones.pm line 1817,
    <$currentfile> line ...
  * The compiler was previously failing to validate the contents of
    the LENGTH and TOS columns in /etc/shorewall/tcrules. The
    contents of those columns are now validated by the compiler and
    an appropriate  error message is issued if validation fails.
  * The column headings in the tos files are now in the proper
    order. Previously, the SOURCE PORT and DEST PORT columns were
    reversed.
* Sun Feb 26 2012 toganm@opensuse.org
- Update to 4.5.1-Beta2 For more details see changelog.txt and
  releasenotes.txt
  * A typo has been corrected in the blrules man pages.
    Previously, if the interface appearing in the HOSTS column of
    /etc/shorewall6/hosts was not defined in
    /etc/shorewall6/interfaces, then the compiler would terminate
    with  a Perl diagnostic:
    Can't use an undefined value as a HASH reference at
    /usr/share/shorewall/Shorewall/Zones.pm line 1817,
    <$currentfile> line ...
* Wed Feb 22 2012 toganm@opensuse.org
- Update to 4.5.1-Beta For more details see changelog.txt and
  releasenotes.txt
  * The packing of the Shorewall products has been changed. Beginning
    with this release, the packages are:
    + Shorewall Core  -- Core libraries installed in
    /usr/share/shorewall/
    + Shorewall       -- Requires Shorewall Core. Together with
    Shorewall Core, provides IPv4 firewalling.
    + Shorewall6      -- Requires Shorewall. Provides IPv6
    firewalling.
    + Shorewall Lite  -- Requires Shorewall Core. As before.
    + Shorewall6 Lite -- Requires Shorewall Core. As before.
    + Shorewall Init  -- As before
* Sat Jan 21 2012 toganm@opensuse.org
- Update to 4.4.27.3 For more details see changelog.txt and
  releasenotes.txt
  * Previously, if USE_DEFAULT_RT=Yes and 'loose' was specified on
    all providers, then no routing rule targeting the main routing
    table was generated. This has been corrected so that
    USE_DEFAULT_RT=Yes always results in such a rule at
    priority 999.
  * Shorewall 4.4.27 broke Shorewall-init functionality. It is
    restored in this release.
* Mon Jan 16 2012 toganm@opensuse.org
- Update to 4.4.27.2. For more details see changelog.txt and
  releasenotes.txt
  * A long-standing problem with Shorewall's 'save' facility has
    been discovered. The defect can cause rules to be dropped during
    'save' so that they are not available to be reapplied during
    'restore'. This can occur in 'safe-restart' when the prompt is
    not acknowledged or when it is acknowledged with 'n'.
    The problem can occur when:
    a)  There are IPSEC zones or hosts present; and
    b)  GOTO Target support is available in the kernel and
    iptables.
    Example of rule that will be dropped:
  - A eth2_fwd -m policy --dir in --pol ipsec -g AAA_frwd
    The defective code has been corrected so that rules are no
    longer dropped.
* Thu Jan 12 2012 toganm@opensuse.org
- Update to 4.4.27.1. For more details see changelog.txt and
  releasenotes.txt
  * When optimization category 4 is used, unconditional jumps at
    the end of chains are replaced with the rules in the target
    chain. This can result in rulesets that are considerably larger
    than necessary. Beginning with this release, replacement will
    only occur if:
    a) The jump is the only reference to the target chain; or
    b) The target chain contains 3 or less rules.
  * The feature introduced in 4.4.25 that allowed provider names in
    the  'enable' and 'disable' commands was only implemented for
    'enable'. It is now implemented for 'disable' as well.
  * When detecting IPv6 global addresses through an interface,
    Shorewall6-generated scripts were ignoring addresses beginning
    with '3'.
  * A typo in /usr/share/shorewall/prog.header caused an 'awk' script
    to fail when saving a multi-hop default route during 'start'.
  * The value '0' is once again accepted in the IN_BANDWIDTH
    columns of tcinterfaces and tcrules, and causes no ingress
    policing to be configured.
  * MARK_IN_FORWARD_CHAIN=Yes no longer generates an error when
    $FW:<address> is entered in the SOURCE column of the tcrules
    file.
  * In most Shorewall 4.4 versions, if an exported params file
    (EXPORTPARAMS=Yes in shorewall.conf) generates any output to
    stdout, then the following messages would appear during
    start/restart:
    Compiling /etc/shorewall/routestopped...
    Shorewall configuration compiled to
    /var/lib/shorewall/.restart
    printf: 214: Build: expected numeric value
    printf: 214: ipset: expected numeric value
    printf: 214: of: expected numeric value
    Processing /etc/shorewall/params ...
    Build ipset of blacklisted addresses
    Usage: /var/lib/shorewall/.restart [ options ] <command>
    <command> is one of:
    start
    stop
    ...
    This has now been corrected.
* Wed Dec 14 2011 toganm@opensuse.org
- Update to 4.4.26.1 For more details see changelog.txt and
  releasenotes.txt
  * The Perl module version numbers have now been updated to
  reflect changes in 4.4.26.
  * The 4.4.26 rules compiler does not issue a warning when a
  capabilities file was generated with Shorewall 4.4.25, even
  though new capabilities were added in 4.4.26. This has been
  corrected so that a warning is generated.
  * When TC_ENABLED=Shared, CLASSIFY rules could not be used in the
  tcrules file. Thanks to a patch from Chris Boot, this now works
  as expected.
  * The quoted part of the progress message 'Provider "..."
  compiled' was inadvertently omitted by a change in Shorewall 4.4.23.
  That text has now been restored.
* Sat Dec  3 2011 toganm@opensuse.org
- Update to 4.4.26 For more details see changelog.txt and
  releasenotes.txt
  * This release includes all corrections included in 4.4.25.1
    through .3.
  * In 4.4.25, ACCEPT behaved in the BLACKLIST section the same way
    as in the other rules file sections. This could lead to
    connections  being accepted inadvertently.
    Now, ACCEPT behaves like WHITELIST; that is, it exempts the
    packet from the remaining rules in the BLACKLIST section.
  * Previously, Shorewall did not detect the ULOG and NFLOG
    capabilities. This lead to run-time failures during 'start' and
    'restart' as well as confusing error messages during
    compilation  when ULOG or NFLOG was used when the LOG target was
    not available.
    ULOG and NFLOG are now detected capabilities so, if you use a
    capabilities file, you will need to regenerate it in order to
    use these log levels.
  * The SAME tcrules target was broken in Shorewall 4.4.22. It now
    works correctly again.
  * Previously, 'shorewall6 update' did not update shorewall6.conf.
    The command now works as expected.
  * In earlier releases, the compiler was attempting to process the
    params file before it was aware of the setting of CONFIG_PATH.
    This could cause the params file to be missed if it was not located
    in /etc/shorewall[6] or in the directory named in the start
    (restart,compile,check,...) command.
    Now, /sbin/shorewall[6] passes $CONFIG_PATH to the compiler
    (/usr/share/shorewall/compiler.pl) in the new '--config_path'
    option.
* Sat Nov 12 2011 toganm@opensuse.org
- Update to 4.4.25.3  For more details see changelog.txt and
  releasenotes.txt
  * Correction of the produced ruleset when wildchars are used in
    the zone configuration
* Sun Nov  6 2011 toganm@opensuse.org
-  Update to 4.4.25.2 For more details see changelog.txt and
  releasenotes.txt
  * Previously, if all the following were true:
  - AUTOMAKE=Yes
  - Current compiled script (/var/lib/shorewall/firewall or
    /var/lib/shorewall6/firewall) up to date
  - LEGACY_FASTSTART=No
  - There was a saved configuration
    then rather than start the current configuration, 'shorewall
    start -f' or 'shorewall6 start -f' would incorrectly restore
    the saved  configuration.
  * The DropSmurfs and TCPFlags actions are now available in
    Shorewall6. They were previously omitted from the IPv6
    actions.std file.
  * The 'rawpost' table was previously omitted from the output of
    the 'dump' command. It is now displayed.
  * Previously, if a configuration contained more than one wildcard
    interface (physical name ending in '+'), then the generated script
    might not work properly with Shorewall-init. This defect dates back
    to the introduction of Shorewall-init.
* Tue Nov  1 2011 toganm@opensuse.org
- Update to 4.4.25.1 For more details see changelog.txt and
  releasenotes.txt
  * A'refresh' command with no chains or tables specified will
    now reload chains created by entries in the BLACKLIST section of
    the rules file.
  * The rules compiler previously failed to detect the 'Flow
    Filter' capability. That capability is now correctly detected.
  * The IN_BANDWIDTH handling changes in 4.4.25 was incompatible
    with moribund distributions such as RHEL4. Restoring IN_BANDWIDTH
    functionality on those releases required a new 'Basic Filter'
    capability.
* Sun Oct 30 2011 toganm@opensuse.org
- Update to 4.4.25 For more details see changelog.txt and
  releasenotes.txt
  * A defect in the optimizer that allowed incompatible rules to be
  combined has been corrected.
  * Routes and rules added as a result of entries in
  /etc/shorewall6/providers were previously not deleted by
  'stop' or 'restart'. Repeated 'restart' commands could
  therefore  lead to an incorrect routing configuration.
  * Previously, capital letters were disallowed in IPv6 addresses.
  They are now permitted.
  * If the COPY column in /etc/shorewall6/providers was non-empty,
  previously a run-time error could occur when copying a table.
  The diagnostic produced by ip was:
    Either "to" is duplicate, or "cache" is garbage
  * When copying IPv6 routes, the generated script previously
  attempted to copy 'cache' entries. Those entries are now omitted.
  * Previously, the use of large provider numbers could cause some
  Shorewall-generated routing rules to be ineffective.
  * In some contexts, IPv6 addresses of the form ::i.j.k.l were
  incorrectly classified as invalid by the configuration compile
  * New blacklisting facility implemented. For this and other new
  features please refer to the releasenotes.txt
* Sat Oct 15 2011 toganm@opensuse.org
- Update to 4.4.24.1
  * When the logical and physical name of an interface were
    different, including the logical name in the tcdevices file
    caused the device's classes to be ignored. This defect was
    introduced in  Shorewall 4.4.23.
  * Remove the ExecReload from all services, since systemd
    doesn't allow an ExecReload for OneShot services. Also, add a
    missing After=network.target to shorewall.service.
- Fixed Url typo in the spec
* Mon Oct 10 2011 toganm@opensuse.org
- Update to 4.4.24. For more details see changelog.txt and
  releasenotes.txt
  * This release includes all problem corrections from releases
    4.4.23.1-4.4.23.3.
  * The 'fallback' option without =<weight> previously produced
    invalid  'ip' commands.
* Thu Sep 29 2011 toganm@opensuse.org
- reworked systemd related rpm macros for 12.1
* Sat Sep 17 2011 toganm@opensuse.org
- Update to 4.4.23.3
  * When providers were present that specify neither 'balance' nor
    'fallback', then the following message was issued during
    compilation and 'enable' of the interface would fail.
    Use of uninitialized value $weight in concatenation (.) or
    string  at /usr/share/shorewall/Shorewall/Providers.pm line 644.
  * TC_ENABLED=Shared was broken in Shorewall 4.4.23, 4.4.23.1 and
    4.4.23.2. It produced a  shell script with syntax errors.
- Backported patches removed.
* Fri Sep 16 2011 toganm@opensuse.org
- Update to 4.4.23.2  For more details see changelog.txt and
  releasenotes.txt
- Support of systemd for openSUSE 12.1
- Backported patches WEIGHT.patch and SHARED.patch fixing a
  harmless message and traffic shaping issues respectively
* Sat Aug 20 2011 toganm@opensuse.org
- Update to 4.4.22.3. Corrections in this release are below.
  * On older distributions where 'shorewall show capabilities'
    indicates 'Connection Tracking Match: Not Available', harmless
    Perl diagnostics like the following could be issued:
    Use of uninitialized value $list in pattern match (m//)
    at /usr/share/shorewall/Shorewall/Config.pm line 1273,
    <$currentfile> line 14.
    Use of uninitialized value $list in split
    at /usr/share/shorewall/Shorewall/Config.pm line 1275,
    <$currentfile> line 14.
  * On older distributions where 'shorewall show capabilities'
    indicates 'Mangle FORWARD Chain: Not Available', entries in the
    ecn file generated the following Perl Diagnostic:
    Use of uninitialized value in hash element
    at /usr/share/shorewall/Shorewall/Chains.pm line 1119.
  * Previously, if a provider interface was derived from an optional
    wildcard entry in /etc/shorewall/providers, then the interface
    was never considered to be usable.
    Example:
    /etc/shorewall/interfaces:
    [#]ZONE    INTERFACE   BROADCAST    OPTIONS
    net ppp+     -  optionsl
    /etc/shorewall/providers:net
    [#]PROVIDER  NUMBER  MARK  INTERFACE ...
    ISP1   1   1 ppp0
  * When 'shorewall update' or 'shorewall6 update' results in no change
    to the .conf file, a message is issued, the .bak file is removed
    and the command terminates without error.
* Fri Aug 12 2011 toganm@opensuse.org
-  patch the Perl diagnostic with a WARNING  message.
* Tue Aug  9 2011 toganm@opensuse.org
- Update to 4.4.22.2
  * On older distributions where 'shorewall show capabilities'
    indicates 'Connection Tracking Match: Not Available', Shorewall
    4.4.22 and 4.4.22.1 generated invalid iptables-restore input.
  * Previously, the compiler always placed '#!/bin/sh' on the first
    line of the generated script. It now uses the setting of
    SHOREWALL_SHELL on that line rather than '/bin/sh'. Note that
    SHOREWALL_SHELL defaults to '/bin/sh' so this change only affects
    those who specify a different shell.
- Patched REDIRECT rule
* Thu Aug  4 2011 toganm@opensuse.org
- Update to 4.4.22.1
  * Previously, if the name of a zone began with 'all', then entries
    for that zone in /etc/shorewall/rules and /etc/shoreawll6/rules
    treated the name the same as 'all'.
    This defect is present in Shorewall 4.4.13 through 4.4.22.
  * Previously, when LOAD_HELPERS_ONLY=No, harmless
    iptables-restore  warnings as follows could be generated:
    ...
    Running   /usr/local/sbin/iptables-restore...
  - -set option deprecated, please use --match-set
  - -set option deprecated, please use --match-set
    IPv4 Forwarding Enabled
* Wed Aug  3 2011 toganm@opensuse.org
- Update to 4.4.22. For more details see changelog.txt and
  releasenotes.txt
  * Under rare conditions, long port lists (>15 ports) could result in
  the following failure when optimization level 4 was enabled.
    Use of uninitialized value in numeric gt (>)
    at /usr/share/shorewall/Shorewall/Chains.pm line 1264.
    ERROR: Internal error in
    Shorewall::Chains::decrement_reference_count at
    /usr/share/shorewall/Shorewall/Chains.pm line 1264
  * All corrections included in Shorewall 4.4.21.1.
- A bug in recent versions of Shorewall that could result in rules
  that are  wider in scope than intended was fixed by applying a patch
  by the upstream.
* Tue Jul 19 2011 toganm@opensuse.org
- Update to 4.4.21.1 Changes in this release are:
  * A harmless Perl run-time "uninitialized variable" diagnostic has
  been eliminated from the compiler. The diagnostic was issued while
  displaying the capabilities.
  * As the result of a typo, an orphan filter chain named FORWAR
  could be created under rare circumstances. This chain was deleted
  by OPTIMIZE level 4.
  * The SNAT options --persistent and --randomize now work properly
  (/etc/shorewall/masq).
  * The LOGMARK log level was previously generated invalid iptables
  input making it unusable. That has been corrected.
  The syntax for LOGMARK is now:
  LOGMARK(<priority>) where <priority> is a syslog priority (1-7 or debug,
  info, notice,  etc.).
  Example rule:
    [#]ACTION           SOURCE  DEST   PROTO   DEST
    [#]                        PORT(S)
    LOG:LOGMARK(info)  lan    dmz    udp     1234
* Mon Jul 11 2011 toganm@opensuse.org
- Update to 4.4.21 For more details see changelog.txt and
  releasenotes.txt
  * The Shorewall and Shorewall6 'load' and 'reload' commands
  now use the .conf file in the current working directory.
  * The 'balance' and 'fallback' options in /etc/shorewall/providers
  have always been mutually exclusive but the compiler previously
  didn't enforce that restriction. Now it does.
  * The ipset modules are now automatically loaded by Shorewall6 when
  LOAD_HELPERS_ONLY=No is specified in shorewall6.conf. Additionally,
  there is now a /usr/share/shorewall6/modules.ipset file that
  lists  all of the required modules.
  * TPROXY descriptions have been added to shorewall-tcrules(5) and
  shorewall6-tcrules(5).
* Thu Jun 16 2011 toganm@opensuse.org
- Update to 4.4.20.3. Changes in this release are
  * Deprecated options have been removed from the .conf files.
  They remain in the man pages.
  * A simple configuration like the 'Universal' sample that includes a
  single wildcard interface ('+' in the INTERFACE column) produces a
  ruleset that blocks all incoming packets.
  As part of correcting this defect, which was introduced in
  4.4.20.2, one or more superfluous rules (which could never
  match) have been eliminated from most configurations.
* Wed Jun 15 2011 toganm@opensuse.org
- Update to 4.4.20.2
  * A defect introduced in 4.4.20 could cause the following failure at
    start/restart:
    ERROR: Command "tc qdisc add dev eth0 parent 1:11 handle 1:
    sfq quantum 12498 limit 127 perturb 10" failed
  * The 'sfilter' interface option introduced in 4.4.20 was only
    applied to forwarded traffic. Now it is also applied to traffic
    addressed to the firewall itself.
  * Issues with iptables-restore is corrected
  * IPSEC traffic is now (correctly) excluded from sfilter.
  * The following incorrect warning message has been eliminated:
    WARNING: sfilter is ineffective with FASTACCEPT=Yes
* Tue Jun  7 2011 toganm@opensuse.org
- Update to 4.4.20.1
  * The address of the Free Software Foundation has been corrected in
  the License files.
  * The shorewall[6].conf file installed in
    /usr/share/shorewall[6]/configfiles is no longer modified for use
    with Shorewall[6]-lite. When creating a new configuration for a
    remote forewall, two lines need to be modified in the copy
    CONFIG_PATH=/usr/share/shorewall (or shorewall6)
    STARTUP_LOG=/var/log/shorewall-lite-init.log
    (or shorewall6-lite-init.log)
* Mon Jun  6 2011 toganm@opensuse.org
- Update to 4.4.20
  * Removed backported patches for openSUSE specific locations as
  they are incorporated in upstream.
- Changes in 4.4.20 (for more read changelog.txt and releasenotes.txt)
  * Support for the AUDIT target has been added. AUDIT is a feature of
  the 2.6.39 kernel and iptables 1.4.10 that allows security auditing
  of access decisions.
* Wed May 18 2011 toganm@opensuse.org
- Update to 4.4.19.4
  * Previously, the compiler would allow a degenerate entry (only the
  BAND specified) in /etc/shorewall/tcpri. Such an entry now raises a
  compilation error.
  * Previously, it was possible to specify tcfilters and tcrules that
  classified traffic with the class-id of a non-leaf HFSC class. Such
  classes are not capabable of handling packets.
  Shorewall now generates a compile-time warning in this case and
  ignores the entry.
  If a non-leaf class is specified as the default class, then
  Shorewall now generates a compile-time error since that
  configuration allows no network traffic to flow.
  * Traditionally, Shorewall has not checked for the existance of
  ipsets mentioned in the configuration, potentially resulting in a
  run-time start/restart failure. Now, the compiler will issue a
  WARNING if:
  a) The compiler is being run by root.
  b) The compilation isn't producing a script to run on a remote
  system under a -lite product.
  c) An ipset appearing in the configuration does not exist on the
  local system.
  * As previously implemented, the 'refresh' command could fail or
  could result in a ruleset other than what was intended. If there
  had been changes in the ruleset since it was originally
  started/restarted/restored that added or deleted sequenced chains
  (chains such as ~lognnn and ~exclnnn), the resulting ruleset could
  jump to the wrong such chains or could fail to 'refresh'
  successfully.
  This issue has been corrected as follows. When a 'refresh' is done
  and individual chains are involved, then each table that contains
  both sequenced chains and one of the chains being refreshed is
  refreshed in its entirety.
  For example, if 'shorwall refresh foo' is issued and the filter
  table (which is the default) contains any sequenced chains, then
  the entire table is reloaded. Note that this reload operation is
  atomic so no packets are passed through an inconsistent
  configuration.
  * When 'shorewall6 refresh' was run previously, a harmless
  'ip6tables: Chain exists' message was generated.
- Reworked backported patches so shorewall still uses openSUSE specific
  locations
- Fix the zone definitions in shorewall6/Samples6/zones examples
* Wed May 11 2011 toganm@opensuse.org
- Update to 4.4.19.3
  * incompatibility with gawk has been corrected
  * Previously, an entry in the USER/GROUP column in the rules and
  tcrules files could cause run-time start/restart failures if the
  rule(s) being added did not have the firewall as the source (rules
  file) and were not being added to the POSTROUTING chain (:T
  designator in the tcrules file). This error is now caught by
  the compiler.
  * Shorewall now insures that a route to a default gateway exists in
  the main table before it attempts to add a default route through
  that gateway in a provider table. This prevents start/restart
  failures in the rare event that such a route does not exist.
  * CLASSIFY TC rules can apply to traffic exiting only the interface
  associated with the class-id specified in the first column.
  * Fixes start of shorewall6 (bnc#693162)
* Fri May  6 2011 toganm@opensuse.org
- Update to 4.4.19.2 For more details see changelog.txt and
  releasenotes.txt
  * In Shorewall-shell, there was the ability to specify IPSET names in
    the ORIGINAL DEST column of DNAT and REDIRECT rules. That ability,
    inadvertently dropped in Shorewall-perl, has been restored
  * Several problems with complex TC have been corrected:
  * Double exclusion involving ipset lists was previously not detected,
    resulting in anomalous behavior.
* Mon Apr 18 2011 toganm@opensuse.org
- Update to 4.4.19.1
  * Eliminate silly duplicate rule when stopped.
  * Don't believe that all nexthop routes are default routes.
  * Restore :<low port>-<high port> in masq file.
  * Correct default route safe/restore.
- backported paths related patches from git as they are in mainstream
  now
* Wed Apr 13 2011 toganm@opensuse.org
- Shorewall packages have their openSUSE specific locations now
  * Executable files in /usr/lib/shorewall*. These include;
    getparams
    compiler.pl
    wait4ifup
    shorecap
    ifupdown
  * Perl Modules in /usr/lib/perl5/vendor_perl/PERL_VERSION/Shorewall.
- Updated to 4.4.19 (for more info please consult changelog.txt and
  releasenotes.txt)
  * Corrected a problem in optimize level 4 that resulted in the following
  compile-time failure
  Can't use an undefined value as an ARRAY reference at
    /usr/share/shorewall/Shorewall/Chains.pm line 862.
  * If a DNAT or REDIRECT rule applied to a source zone with an interface
  defined with 'physical=+', then the nat table 'dnat' chain might have
  been created but not referenced. This prevented the DNAT or REDIRECT
  rule from working correctly.
  * Previously, if a variable set in /etc/shorewall/params was given a value
  containing shell metacharacters, then the compiled script would contain
  syntax errors.
  * The pathname of the 'conntrack' binary was erroneously printed in the
  output of 'shorewall6 show connections'.
  * Correct a problem whereby incorrect Netfilter rules were generated when
  a bridge with ports was given a logical name.
  * If a bridge interface had subordinate ports defined in
  /etc/shorewall/interface, then an ipsec entry (either ipsec zone or the
  'ipsec' option specified) in /etc/shorewall/hosts resulted in the
  compiler generating an incorrect Netfilter configuration.
  * A fatal error is now raised if '!0' appears in the PROTO column of files
  that have that column. This avoids an iptables-restore failure at run time.
* Mon Apr  4 2011 toganm@opensuse.org
- Updated to 4.4.18.2
  * SAVE_IPSETS=Yes didn't work unless there is a dynamic zone defined.
  * If a logical name was given to a bridge and the ports on the bridge
  were defined in /etc/shorewall/interfac, then the compiler could
  generate matches that used the logical name rather than the
  physical name.
* Mon Mar 21 2011 toganm@opensuse.org
- Updated to 4.4.18.1
  * An issue with params processing on RHEL6 has been corrected. The
  problem manifested as the following type of warning:
    WARNING: Param line (export OLDPWD) ignored at
    /usr/share/shorewall/Shorewall/Config.pm line 2993.
  * The editing of the value of the TC_PRIOMAP option has been
  tightened. Previously, many invalid settings were allowed,
  resulting in run-time tc command failures.
  * The Shorewall Lite and Shorewall6 Lite installers now install the
  'helpers' modules file. Previously, this file was not installed
  with the result that both 'shorewall[6]-lite show capabilities' and
  'shorecap' failed.
  * Previously, if an icmp or icmp6 type which included both a type and
  a code was used in the tcfilters file, 'start' and 'restart' would
  fail with a 'tc' error.
* Fri Mar 11 2011 toganm@opensuse.org
- Updated to 4.4.18
  * for accounting modules xtables-addons must be installed
- Changes in 4.4.18 (for more read changelog.txt and releasenotes.txt)
  * The modules files are now just a driver that INCLUDEs several new
    files and one old file:
  * Beginning with Shorewall 4.4.18, the accounting structure can be
    created with three root chains:
  - accountin:  Rules that are valid in the INPUT chain (may not
    specify an output interface).
  - accountout: Rules that are valid in the OUTPUT chain (may not
    specify an input interface or a MAC address).
  - accountfwd: Other rules.
  * Internals Change: The Policy.pm module has been merged into the
    Rules.pm module.
* Thu Feb 10 2011 toganm@opensuse.org
- Updated to 4.4.17
  * This release adds support for per-IP accounting using the ACCOUNT
    target. That target is only available when xtables-addons is
    installed.
- Changes in 4.4.17 (for more read changelog.txt and releasenotes.txt)
  * Previously, Shorewall did not check the length of the names of
    accounting chains and manual chains. This could result in
    errors when loading the resulting ruleset. Now, the compiler issues
    an error for chain names longer than 29 characters.
    Additionally, the compiler now ensures that these chain names are
    composed only of letters, digits, underscores ('_') and dashes
    ("-"). This eliminates Perl runtime errors or other failures when a
    chain name is embedded within a regular expression.
  * Several issues with complex traffic shaping have been resolved:
    a) Specifying IPv6 network addresses in the SOURCE or DEST columns
    of /etc/shorewall6/tcfilters now works correctly. Previously,
    Perl runtime warnings occurred and an invalid tc command was
    generated.
    b) Previously, if flow= was specified on a parent class, a perl
    runtime warning occurred and an invalid tc command was
    generated. This combination is now flagged as an error at
    compile time.
  c) There is now an ipv6 tcfilters skeleton included with
    Shorewall6.
  * Several issues with accounting are corrected.
    a)  If an accounting rule of the form:
    chain1        chain2
    was configured and neither chain was referenced again in the
    configuration, then an internal error was generated when
    optimize level 4 was selected and OPTIMIZE_ACCOUNTING=Yes.
    b)  If there was only a single accounting rule and that rule
    specified an interface in the SOURCE or DEST columns, then the
    generated ruleset would fail to load when
    OPTIMIZE_ACCOUNTING=Yes.
    c)  If a per-IP accounting table name appeared in more than one
    rule and the specified network was not the same in all
    occurrences, then the generated ruleset would fail to load.
    This is now flagged as an error at compile time.
  * Two defects in compiler module loading have been corrected:
    a) Previously, the kernel/net/ipv6/netfilter/ directory was not
    searched.
    b) A Perl diagnostic was issued when running on a monolithic kernel
    when the modutils package was installed.
  * A line containing only 'INCLUDE' appearing in an extension script
    now generates a compile-time diagnostic rather than a run-time
    diagnostic.
  * Previously, the uninstall.sh scripts used insserv (if installed) on
    Debian-based systems. These scripts now use the preferred tool
    (updaterc.d).
  * Beginning with 4.4.16, compilation would fail if an empty shell
    variable was referenced in a config file on a system where /bin/sh
    is the Bourne Again Shell (bash).
  * In earlier versions. if OPTIMIZE=8 then the ruleset displayed by
    'check -r' was the same as when OPTIMIZE=0 (unoptimized).
    Similarly, if OPTIMIZE=9 then the ruleset displayed was the same
    as when OPTIMIZE=1.
  * Startup could previously fail on a system where kernel module
    autoloading was not available and where TC_ENABLED=Simple was
    specified in shorewall.conf or shorewall6.conf.
  * Previously, a 'done.' message could be printed at the end of
    command processing even when the command had failed. Now, such a
    message only appears if the command completed successfully.
* Sat Jan 22 2011 toganm@opensuse.org
- Updated to 4.4.16.1
  * Beginning with 4.4.16, compilation would fail if an empty shell
    variable was referenced in a config file on a system where /bin/sh
    is the Bourne Again Shell (bash).
* Wed Jan 12 2011 toganm@opensuse.org
- fix fillup for shorewall-init so it will be copied to sysconfig
  directory
- link network/scripts/shorewall to if-up.d and if-down.d
- Changes in 4.4.16 (for more read changelog.txt and releasenotes.txt)
  +  If the output of 'env' contained a multi-line value, then
    compilation failed with an Internal Error. The code has been
    changed so that the compiler now handles multi-line values
    correctly.
  * In 4.4.15, output to Standard Out (FD 1) generated by
    /etc/shorewall/params (/etc/shorewall6/params) was redirected to
    /dev/null. It is now redirected to Standard Error (FD 2).
  * If a params file did not appear in the CONFIG_PATH, compilation
    failed with the error:
    .: 31: Can't open /etc/shorewall6/params
    ERROR: Processing of /etc/shorewall6/params failed
  * Previously, proxy ARP with logical interface names did not
    work. Symptoms included numerous Perl runtime error messages.
  * Previously, the root of a wildcard name erroneously matched that
    name. For example 'eth' matched 'eth+'. Now there must be at least
    one additional character (e.g., 'eth4').
  * Use of logical interface names in the notrack and ecn files
    resulted in perl runtime warning messages.
  * The use of wildcard-matching names in certain contexts would result
    in anomalous behavior. Among the symptoms were:
  - Perl run-time messages similar to this one:
    Use of uninitialized value in numeric comparison (<=>)
    at /usr/share/shorewall/Shorewall/Zones.pm line 1334.
  - Failure to treat the interface as optional or required.
  * Where two ISPs share the same interface, if one of the ISPs was not
    reachable, an iptables-restore error such as this occurred:
    iptables-restore v1.4.10: Bad mac address "-j"
  * Previously, under very rare circumstances, a chain would be
    optimized away while there were still jumps to the chain. This caused
    Shorewall start/restart to fail during iptables-restore.
  11) Previously, the setting of BLACKLIST_DISPOSITION was not
    validated. Now, an error is raised unless the value is DROP or REJECT.
* Mon Jan  3 2011 toganm@opensuse.org
- Update to version 4.4.15.3
- Changes in 4.4.15.3
  * Previously, the root of a wildcard name erroneously matched that
    name. For example 'eth' matched 'eth+'. Now there must be at least
    one additional character (e.g., 'eth4').
  * Use of logical interface names in the notrack and ecn files
    resulted in perl runtime warning messages.
  * The use of wildcard-matching names in certain contexts would result
    in perl run-time messages similar to this one:
    Use of uninitialized value in numeric comparison (<=>)
    at /usr/share/shorewall/Shorewall/Zones.pm line 1334.
  * Under very rare circumstances, a chain could be optimized away
    even when there are jumps to the chain. This resulted in a
    start/restart failure.
- Changes in 4.4.15.2
  * Previously, proxy ARP with logical interface names did not
    work. Symptoms included numerous Perl runtime error messages.
  * Previously, unknown interface names in the proxyarp and
    tcinterfaces files resulted in Perl runtime errors.
* Thu Dec  2 2010 toganm@opensuse.org
- Upgrade to version 4.4.15.1
- Changes in version 4.4.15.1
  1)  If the output of 'env' contained a multi-line value, then
    compilation failed with an Internal Error. The code has been
    changed to ignore all but the first line of a multi-line value.
  2)  If a params file did not appear in the CONFIG_PATH, compilation
    failed with the error:
    .: 31: Can't open /etc/shorewall6/params
    ERROR: Processing of /etc/shorewall6/params failed
* Thu Dec  2 2010 toganm@opensuse.org
- Update to version 4.4.15
- Changes in Shorewall 4.4.15
  1)  Add macros from Tuomo Soini.
  2)  Corrected macro.JAP.
  3)  Added fatal_error() functions to the -lite CLIs.
  RC 1
  1)  Another Perl 5.12 warning.
  2)  Avoid anomalous behavior regarding syn flood chains.
  3)  Add HEADERS column for IPv6
  Beta 2
  1)  Tweaks to IPv6 tcfilters
  2)  Add support for explicit provider routes
  3)  Fix shared TC tcfilters handling.
  Beta 1
  1)  Handle exported VERBOSE.
  2)  Modernize handling of the params file.
  3)  Fix NULL_ROUTE_RFC1918
  4)  Fix problem of appending incorrect files.
  5)  Implement shared TC.
* Thu Nov 25 2010 toganm@opensuse.org
- Added README.openSUSE which warns the user
* Wed Nov 24 2010 toganm@opensuse.org
- Fix init-4.4.14.patch
- Cleaned spec file
- Removed Provides shoreline_firewall
- Until upstream clarifies non-executable scripts put them under rpmlintrc
- TODO
  * the code files should  go into %%_libexecdir/shorewall, only non-executable
  data is for  %%_datadir/shorewall.
* Wed Nov 24 2010 toganm@opensuse.org
- Included docs-html to the packaging as well
- Patches have the version number reflecting the diff to the original
* Thu Nov 11 2010 toganm@opensuse.org
- Initial packaging of shorewall for opensuse
